Package: RaCE.NMA
Title: Rank-Clustered Estimation for Network Meta-Analysis
Version: 1.0.3
Authors@R: c(
    person("Michael", "Pearce", , "michaelpearce@reed.edu", role = c("aut", "cre","cph"),
           comment = c(ORCID = "0000-0002-9313-271X")),
    person("Shouhao", "Zhou", , "szhou1@pennstatehealth.psu.edu", role = c("aut"),
            comment = c(ORCID = "0000-0002-8124-5047")))
Description: An implementation of the RaCE-NMA (Rank-Clustered
    Estimation for Network Meta-Analysis) model for post-hoc clustering
    of treatments or interventions by rank in network  meta-analysis
    data. Functions for model estimation, assessment, and displaying 
    results are provided. For more details, see Pearce and Zhou (2025) 
    <doi:10.1017/rsm.2025.10049>.
License: GPL (>= 3)
Encoding: UTF-8
RoxygenNote: 7.3.3
LazyData: TRUE
Imports: utils, magrittr, dplyr, invgamma, mvtnorm, coda, reshape2,
        ggplot2
Suggests: knitr, rmarkdown, devtools, cowplot, gridExtra
VignetteBuilder: knitr
URL: https://pearce790.github.io/RaCE.NMA/,
        https://github.com/pearce790/RaCE.NMA/
BugReports: https://github.com/pearce790/RaCE.NMA/issues
NeedsCompilation: no
Packaged: 2026-05-28 23:15:08 UTC; michaelpearce
Author: Michael Pearce [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0002-9313-271X>),
  Shouhao Zhou [aut] (ORCID: <https://orcid.org/0000-0002-8124-5047>)
Maintainer: Michael Pearce <michaelpearce@reed.edu>
Depends: R (>= 3.5.0)
Repository: CRAN
Date/Publication: 2026-06-02 07:50:42 UTC
Built: R 4.5.2; ; 2026-06-02 08:50:56 UTC; unix

# Generated by roxygen2: do not edit by hand

export(calculate_Rhat)
export(calculate_SUCRA_MNBT)
export(clusterplot_ranks)
export(cumulativeprobplot_ranks)
export(fit_raceNMA)
export(forestplot_muhat)
export(mcmc_raceNMA)
export(sample_partition_correlation)
export(sample_partition_independence)
export(traceplot_K)
export(traceplot_mu)
import(coda)
import(dplyr)
import(ggplot2)
import(invgamma)
import(mvtnorm)
import(reshape2)
import(utils)
importFrom(dplyr,filter)
importFrom(dplyr,select)
importFrom(magrittr,"%>%")
importFrom(stats,dnorm)
importFrom(stats,na.exclude)
importFrom(stats,quantile)
importFrom(stats,rbinom)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,var)

RaCE.NMA
-----

The ``RaCE.NMA`` R package implements the the Rank-Clustering Estimation model for Network Meta-Analysis (RaCE-NMA) proposed by [Pearce and Zhou (2025)](https://doi.org/10.1017/rsm.2025.10049).

Where can I learn more? 
-----

To learn more about the methodology implemented by this package, check out our [paper](https://doi.org/10.1017/rsm.2025.10049) in the journal *Research Synthesis Methods*.

For instructions on downloading the `RaCE.NMA` R package from Github, see the [Overview](https://pearce790.github.io/RaCE.NMA/articles/overview.html) tab. 

After downloading, check out the following articles:

  + [Tutorial](https://pearce790.github.io/RaCE.NMA/articles/tutorial.html) for examples of how to use the package's key R functions.
  + [Reproducibility](https://pearce790.github.io/RaCE.NMA/articles/reproducibility.html) for code to replicate the paper.
  + [Reference](https://pearce790.github.io/rankclust/reference/index.html) for a list of functions and links to associated documentation.

Acknowledgements and Funding
-----

This project is partially supported by NIH Grant R21LM014534. The content is solely the responsibility of the authors and does not necessarily represent the official views of the National Institutes of Health.

## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  warning=FALSE,
  comment = "#>"
)
options(rmarkdown.html_vignette.check_title = FALSE)

## ----warning=FALSE,message=FALSE----------------------------------------------
library(RaCE.NMA)
library(reshape2) # data reformatting
library(ggplot2)  # creating nice figures

## -----------------------------------------------------------------------------
data("toy_data")
head(toy_data)

## ----fig.asp=0.45, fig.cap="Figure 1: Forest plot of estimated relative treatment effects in a toy example dataset, based on a standard NMA model."----
forestplot_muhat(data = toy_data, level = 0.95, 
                  order_by_average = FALSE)

## ----eval=FALSE---------------------------------------------------------------
# mcmc_raceNMA(posterior = toy_data)

## ----eval=TRUE----------------------------------------------------------------
mu_hat_toy <- apply(toy_data, 2, mean)
cov_toy <- cov(toy_data)
s_toy <- apply(toy_data, 2, sd)

## ----eval=FALSE---------------------------------------------------------------
# mcmc_raceNMA(mu_hat = mu_hat_toy, cov = cov_toy) # example with mu_hat and cov
# mcmc_raceNMA(mu_hat = mu_hat_toy, s   = s_toy  ) # example with mu_hat and s

## ----eval=FALSE---------------------------------------------------------------
# mcmc_raceNMA(
#   posterior = toy_data, # results of a standard NMA model
#   mu0 = mean(mu_hat_toy), sigma0 = sqrt(10*var(mu_hat_toy)), # model hyperparameters
# )

## -----------------------------------------------------------------------------
mcmc_results_toy <- mcmc_raceNMA(
  posterior = toy_data, # results of a standard NMA model
  mu0 = mean(mu_hat_toy), sigma0 = sqrt(10*var(mu_hat_toy)), # model hyperparameters
  iter = 10000, nu_iter = 2, # MCMC settings
  chains = 2, burn_prop = 0.5, thin = 1, seed = 1
)

## ----fig.cap="Figure 2: Trace plots of relative treatment effects in a toy example dataset, based on the RaCE-NMA model."----
traceplot_mu(mcmc_results_toy)

## ----fig.cap="Figure 3: Trace plot of the number of rank-clusters, K, in a toy example dataset, based on the RaCE-NMA model."----
traceplot_K(mcmc_results_toy)

## ----fig.cap="Table 1: R-hat statistics for the relative treatment effects in a toy example dataset, based on the RaCE-NMA model."----
calculate_Rhat(mcmc_results_toy, level = 0.9)

## ----fig.asp=0.6, fig.cap="Figure 4: Posterior rank probabilities for each intervention in a toy example dataset, based on the RaCE-NMA model. Ranks are displayed on the ordinal scale (1 = best). Interventions are grouped into rank clusters representing non-exclusive superiority sets; multiple interventions within the same cluster may share identical posterior ranks."----
clusterplot_ranks(mcmc=mcmc_results_toy, label_ranks = 1:4)

## ----fig.asp=0.4, fig.cap="Figure 5: Cumulative ranking probability curves for each intervention in a toy example dataset, based on the RaCE-NMA model."----
cumulativeprobplot_ranks(mcmc=mcmc_results_toy)

## ----fig.cap="Table 2: SUCRA and MNBT statistics for each intervention in a toy example dataset, based on the RaCE-NMA model."----
calculate_SUCRA_MNBT(mcmc=mcmc_results_toy, level = 0.5)

## -----------------------------------------------------------------------------
data("wang_posterior")
round(head(wang_posterior), 3)

## -----------------------------------------------------------------------------
# define assumed mean and variance for baseline treatment (R-CHOP)
mu_hat_baseline <- 0
var_baseline <- min(apply(wang_posterior,2,var))/10

# calculate summary statistics, mu_hat and cov
mu_hat_wang <- c( mu_hat_baseline, apply(wang_posterior,2,mean) )
cov_wang <- cbind( c(var_baseline, rep(0, 10) ),
              rbind(0, cov(wang_posterior)) )

# store treatment names
treatments <- c("R-CHOP", names(wang_posterior))

## ----fig.asp=0.5, fig.cap="Figure 6: Forest plot of estimated relative treatment effects in a network meta-analysis by Wang et. al (2022), based on a standard NMA model."----
forestplot_muhat(data = cbind(0,wang_posterior), 
                 names = treatments)

## ----cache=TRUE---------------------------------------------------------------
mcmc_results_casestudy <- mcmc_raceNMA(
  mu_hat = mu_hat_wang, cov = cov_wang,
  iter = 10000, nu_iter = 2, chains = 2, seed = 1
)

## ----fig.cap="Figure 7: Trace plots of relative treatment effects in a network meta-analysis by Wang et. al (2022), based on the RaCE-NMA model."----
traceplot_mu(mcmc_results_casestudy, names=treatments)

## ----fig.cap="Figure 8: Trace plot of the number of rank-clusters, K, in a network meta-analysis by Wang et. al (2022), based on the RaCE-NMA model."----
traceplot_K(mcmc_results_casestudy)

## ----fig.cap="Table 3: R-hat statistics for the relative treatment effects in a network meta-analysis by Wang et. al (2022), based on the RaCE-NMA model."----
calculate_Rhat(mcmc_results_casestudy, names=treatments)

## ----fig.asp=0.6, fig.cap="Figure 9: Posterior rank probabilities for each intervention in a network meta-analysis by Wang et. al (2022), based on the RaCE-NMA model. Ranks are displayed on the ordinal scale (1 = best). Interventions are grouped into rank clusters representing non-exclusive superiority sets; multiple interventions within the same cluster may share identical posterior ranks."----
clusterplot_ranks(mcmc=mcmc_results_casestudy, names = treatments, label_ranks = 1)

## ----fig.asp=0.4, fig.cap="Figure 10: Cumulative ranking probability curves for each intervention in a network meta-analysis by Wang et. al (2022), based on the RaCE-NMA model."----
cumulativeprobplot_ranks(mcmc=mcmc_results_casestudy, names=treatments)

## ----fig.cap="Table 4: SUCRA and MNBT statistics for each intervention in a network meta-analysis by Wang et. al (2022), based on the RaCE-NMA model."----
calculate_SUCRA_MNBT(mcmc=mcmc_results_casestudy,names=treatments,level=0.50)

## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  warning = FALSE,
  eval=FALSE
)

## ----warning=FALSE, message=FALSE---------------------------------------------
# library(RaCE.NMA)
# library(ggplot2)
# library(dplyr)
# library(cowplot)
# library(gridExtra)
# library(reshape2)

## ----fig.asp=0.35-------------------------------------------------------------
# s <- 0.1
# g1a<-ggplot()+scale_x_continuous(limits=c(-3*s,1+3*s))+
#   stat_function(fun = dnorm, args = list(mean = 0, sd =s))+
#   stat_function(fun = dnorm, args = list(mean = 1, sd =s))+
#   theme_bw()+labs(x=" ",y="Density",subtitle=expression(hat(sigma)~"=0.1"))+
#   theme(panel.grid.minor = element_blank(),panel.grid.major.y = element_blank())
# s <- 0.3
# g1b<-ggplot()+scale_x_continuous(limits=c(-3*s,1+3*s))+
#   stat_function(fun = dnorm, args = list(mean = 0, sd =s))+
#   stat_function(fun = dnorm, args = list(mean = 1, sd =s))+
#   theme_bw()+labs(x="Posterior Intervention Effects",y=NULL,subtitle=expression(hat(sigma)~"=0.3"))+
#   theme(panel.grid.minor = element_blank(),panel.grid.major.y = element_blank())
# s <- 0.5
# g1c<-ggplot()+scale_x_continuous(limits=c(-3*s,1+3*s))+
#   stat_function(fun = dnorm, args = list(mean = 0, sd =s))+
#   stat_function(fun = dnorm, args = list(mean = 1, sd =s))+
#   theme_bw()+labs(x=" ",y=NULL,subtitle=expression(hat(sigma)~"=0.5"))+
#   theme(panel.grid.minor = element_blank(),panel.grid.major.y = element_blank())
# grid.arrange(g1a,g1b,g1c,nrow=1)

## ----cache=TRUE---------------------------------------------------------------
# ## Perform simulation study
# set.seed(1)
# results <- matrix(NA,nrow=0,ncol=6)
# for(iter in 1:20){
#   for(J in c(6,12,18)){
#     for(K in c(J/3,2*J/3,J)){
#       for(s in c(0.1,0.3,0.5)){
#         if(K==J){
#           mu_hat <- 1:K
#         }else{
#           mu_hat <- sample(1:K,J,replace=T)
#           while(length(unique(mu_hat))<K){mu_hat <- sample(1:K,J,replace=T)}
#         }
# 
#         mcmc <- mcmc_raceNMA(mu_hat = mu_hat,s=rep(s,J),mu=mean(mu_hat),
#                              sigma0=max(1,4*sd(mu_hat)),nu0=mu_hat,
#                              tau=1,iter=3000,nu_iter=2,chains=4,
#                              burn_prop=0.5,thin=3,verbose = FALSE)
# 
#         equal <- posterior_equal <- matrix(NA,nrow=J,ncol=J)
#         for(i in 1:(J-1)){for(j in (i+1):J){
#           equal[i,j] <- ifelse(mu_hat[i]==mu_hat[j],1,0) # test if treatments are truly equal in mean
#           posterior_equal[i,j] <- mean( # assess if treatments are rank-clustered
#             mcmc[,paste0("G",i)] == mcmc[,paste0("G",j)]
#             )
#         }}
# 
#         results <- rbind(
#           results,
#           c(iter,J,K,s,
#             mean(posterior_equal[equal==1],na.rm=T),
#             mean(posterior_equal[equal==0],na.rm=T))
#         )
#       }
#     }
#   }
# }

## -----------------------------------------------------------------------------
# ## Plotting results from simulation study
# results <- as.data.frame(results)
# names(results) <- c("Iteration","J","K","s","Prob_Clustered","Prob_Distinct")
# results$s<-factor(results$s, levels=c(.1,.3,.5),
#                   labels=c(expression(hat(sigma)~"=0.1"),
#                            expression(hat(sigma)~"=0.3"),
#                            expression(hat(sigma)~"=0.5")))
# results$J <- factor(results$J,levels=c(6,12,18),
#                     labels=c(expression(J~"= 6"),
#                              expression(J~"= 12"),
#                              expression(J~"= 18")))
# results_melt <- melt(results,id.vars=1:4)
# results_melt <- results_melt[!is.nan(results_melt$value),] # drop "cluster" cases when K=J
# ggplot(results_melt,aes(x=factor(K),y=value,
#                         color=factor(variable,labels=c("Rank-Clustered","Distinct"))))+
#   facet_grid(s~J,scales="free_x",labeller=label_parsed)+
#   geom_boxplot(outlier.alpha=0.5,position="identity")+theme_bw()+
#   scale_color_manual(values=c("skyblue","darkblue"))+
#   labs(x="Number of Rank-Clusters, K",
#        y="Posterior Rank-Clustering Probability",
#        color=NULL)+
#   theme(legend.position = "bottom",
#         panel.grid.minor = element_blank(),
#         panel.grid.major.x = element_blank())

## ----fig.asp = 0.4------------------------------------------------------------
# J <- 4
# mu_hat <- c(-1,0,1,0)
# s <- c(.1,.1,.1,1)
# 
# set.seed(2)
# data <- matrix(data = rnorm(10000*4,mean=mu_hat,sd=s), ncol = 4, byrow = TRUE)
# 
# forestplot_muhat(data = data, order_by_average = FALSE)

## ----cache=TRUE---------------------------------------------------------------
# mcmc <- mcmc_raceNMA(mu_hat = mu_hat, s = s,
#                    iter = 50000, nu_iter = 2, chains = 4,
#                    burn_prop = 0.5,thin = 1,verbose = FALSE)
# 
# posterior_equal <- matrix(NA,nrow=J,ncol=J)
# for(i in 1:(J-1)){for(j in (i+1):J){
#   posterior_equal[i,j] <- mean(mcmc[,paste0("G",i)] == mcmc[,paste0("G",j)])
# }}
# round(posterior_equal,2)

## ----fig.asp-0.6--------------------------------------------------------------
# wang_ranks <- t(apply(data,1,function(mu){rank(mu)}))
# wang_ranks_probs <- apply(wang_ranks,2,function(rank){
#   sapply(1:J,function(j){mean(rank==j)})
# })
# race_ranks <- t(apply( mcmc[,paste0("mu",1:J)], 1, function(mu){
#   rank(mu,ties.method="min")
# }))
# race_ranks_probs <- apply(race_ranks,2,function(rank){
#   sapply(1:J,function(j){mean(rank==j)})
# })
# 
# g4a<-ggplot(melt(wang_ranks_probs),
#             aes(x=Var1,y=factor(Var2),fill=value)) +
#   geom_tile() + theme_minimal() +
#   scale_y_discrete(limits=rev) +
#   scale_x_continuous(breaks=1:4,limits=c(.5,4.5)) +
#   scale_fill_gradient(low="white",high="black",limits=c(0,1))+
#   labs(x="Rank",y="Treatment",fill="Probability")+
#   theme(panel.grid = element_blank(),legend.position = "bottom")+
#   geom_text(aes(x=Var1,y=factor(Var2),label=round(value,2)),
#         color=ifelse(melt(wang_ranks_probs)$value>0.4,"white","black"))
# 
# g4b<-ggplot(melt(race_ranks_probs),
#             aes(x=Var1,y=factor(Var2,levels=paste0("mu",1:J),
#                                 labels=paste0(1:J)),fill=value))+
#   geom_tile() + theme_minimal() +
#   scale_y_discrete(limits=rev) +
#   scale_x_continuous(breaks=1:4,limits=c(.5,4.5)) +
#   scale_fill_gradient(low="white",high="black",limits=c(0,1)) +
#   labs(x="Rank",y="Treatment",fill="Probability")+
#   theme(panel.grid = element_blank(),legend.position = "bottom")+
#   geom_text(aes(x=Var1,y=factor(Var2,levels=paste0("mu",1:J),labels=paste0(1:J)),
#                 label=round(value,2)),
#             color=ifelse(melt(race_ranks_probs)$value>0.4,"white","black"))
# 
# plot_grid(plot_grid(g4a+theme(legend.position = "none"),
#                     g4b+theme(legend.position = "none"),
#                     labels = c('A', 'B'), label_size = 12),
#           get_plot_component(g4a, 'guide-box-bottom', return_all = TRUE),
#           nrow=2,rel_heights = c(.9,.1) )

## -----------------------------------------------------------------------------
# data("wang_posterior") # loads posterior of non-baseline treatments
# 
# # define assumed mean and variance for baseline treatment (R-CHOP)
# mu_hat_baseline <- 0
# var_baseline <- min(apply(wang_posterior,2,var))/10
# 
# # calculate summary statistics, mu_hat and cov, for all treatments
# mu_hat <- c( mu_hat_baseline, apply(wang_posterior,2,mean) )
# cov <- cbind( c(var_baseline, rep(0, 10) ),
#               rbind(0, cov(wang_posterior)) )
# 
# # store treatment names
# treatments <- c("R-CHOP", names(wang_posterior))

## ----fig.asp = 0.4, warning=FALSE---------------------------------------------
# forestplot_muhat(data=wang_posterior,names=treatments[-1])

## -----------------------------------------------------------------------------
# mcmc <- mcmc_raceNMA(mu_hat = mu_hat, cov = cov,
#                    mu0 = mean(mu_hat), sigma0 = sqrt(10*var(mu_hat)),
#                    iter = 50000, nu_iter = 5, chains = 4,
#                    seed = 1, verbose = FALSE)

## ----fig.asp=0.45-------------------------------------------------------------
# # Figure 6
# g9a <- clusterplot_ranks(data=cbind(0,wang_posterior),
#                             names=treatments,label_ranks=1)+
#   theme(legend.position = "bottom")
# g9b <- clusterplot_ranks(mcmc=mcmc,names=treatments,label_ranks = 1)
# plot_grid(plot_grid(g9a+theme(legend.position = "none"),
#                     g9b+theme(legend.position = "none"),
#                     labels = c('A', 'B'), label_size = 12),
#           get_plot_component(g9a, 'guide-box-bottom', return_all = TRUE),
#           nrow=2,rel_heights = c(.9,.1))
# # Figure 7
# g10a <- cumulativeprobplot_ranks(data=cbind(0,wang_posterior),names=treatments)+
#   theme(legend.position = "bottom") +
#   guides(color = guide_legend(nrow = 2))
# g10b <- cumulativeprobplot_ranks(mcmc=mcmc,names=treatments)
# plot_grid(plot_grid(g10a+theme(legend.position = "none"), g10b+theme(legend.position = "none"),
#                         labels = c('A', 'B'), label_size = 12),
#               get_plot_component(g10a, 'guide-box-bottom', return_all = TRUE),
#           nrow=2,rel_heights = c(.85,.15) )
# # Table 2
# res_WANG <- calculate_SUCRA_MNBT(data = cbind(0,wang_posterior),
#                                  level = 0.50, names = treatments)
# res_RaCENMA <- calculate_SUCRA_MNBT(mcmc = mcmc, level = 0.50, names = treatments)
# table2 <- left_join(res_WANG,res_RaCENMA,by="Treatment")[,c(1,2,4,3,5)]
# names(table2) <- c("Treatment","SUCRA (Wang)","SUCRA (RaCE)","MNBT (Wang)","MNBT (RaCE)")
# print(table2)

## ----fig.asp=0.4--------------------------------------------------------------
# traceplot_K(mcmc)+
#   scale_x_continuous(breaks=seq(125000,250000,by=25000),
#                      labels=paste0(seq(125,250,by=25),"k"))
# traceplot_mu(mcmc,names=treatments)+
#   scale_x_continuous(breaks=seq(125000,250000,by=25000),
#                      labels=paste0(seq(125,250,by=25),"k"))
# forestplot_muhat(mcmc=mcmc,names=treatments)

#' Partition sampling in Bayesian RaCE-NMA models (internal use only)
#'
#' This function implements a reversible jump MCMC procedure for updating the parameter partition in Bayesian Rank-Clustered Estimation for Network Meta-Analysis models in the case when we assume independence between treatment effects. For internal use only.
#'
#' @param mu_hat A vector of estimated average relative intervention effects based on a previous NMA. The jth entry is the effect of intervention j.
#' @param J A numeric indicating the total number of interventions being compared.
#' @param nu A vector indicating current values for nu in the Gibbs sampler.
#' @param g A vector indicating current values for g in the Gibbs sampler.
#' @param K A vector indicating current values for K in the Gibbs sampler.
#' @param mu0 The hyperparameter mu0, usually specified as the grand mean of the average intervention effects.
#' @param sigma0 The hyperparameter sigma_0, usually a large number as to be minimally informative.
#' @param s A vector of the estimated standard deviations of each intervention. The jth entry is the standard deviation of intervention j.
#' @param tau The standard deviation of the Metropolis Hastings proposal distribution.
#' @param b_g The probability of "birth"ing a new partition cluster, if possible. Default is 0.5.
#' @param d_g The probability of "death"ing an existing partition cluster, if possible. Default is 0.5.
#'
#' @return A list containing updated values for g, nu, and K.
#'
#' @examples
#' sample_partition_independence(mu_hat=c(1,1,1),J=3,nu=1,g=c(1,1,1),
#' K=1,mu0=1,sigma0=1,s=c(1,1,1),tau=0.1)
#'
#' @export
sample_partition_independence <- function (mu_hat, J, nu, g, K, mu0, sigma0, s, tau = tau, b_g = 0.5, d_g = 0.5){
  logprior_partition <- log(rep(1,J))
  S_g <- unlist(lapply(1:K, function(k) {sum(g == k)}))
  if (rbinom(1, 1, b_g) == 1) {
    ## Birth!
    if (all(S_g == 1)) {
      logprob_accept <- -Inf
    }else {
      which_split <- which(S_g >= 2)
      if (length(which_split) == 1) {k <- which_split
      }else {k <- sample(which_split, 1)}
      new_clusts <- c(1, rbinom(S_g[k] - 1, 1, prob = 0.5))
      while (sum(new_clusts) == 0 | sum(new_clusts) == S_g[k]) {
        new_clusts <- c(1, rbinom(S_g[k] - 1, 1, prob = 0.5))
      }
      u <- rnorm(1,mean=0,sd=tau)
      nu_new <- nu
      nu_new[k] <- nu[k] - u
      nu_new[K + 1] <- nu[k] + u
      g_new <- g
      g_new[which(g == k)[new_clusts == 1]] <- K + 1
      K_new <- K+1
      if (any((min(nu_new[c(k, K + 1)]) <= nu[-k]) & (nu[-k] <= max(nu_new[c(k, K + 1)])))) {
        logprob_accept <- -Inf
      }else {
        logprob_accept <-
          sum(unlist(lapply(1:J,function(j){dnorm(mu_hat[j], mean = nu_new[g_new[j]], sd = s[j],log=T)}))) -
          sum(unlist(lapply(1:J,function(j){dnorm(mu_hat[j], mean = nu[g[j]], sd = s[j],log=T)}))) +
          sum(dnorm(nu_new[c(k, K+1)], mu0, sigma0, log=T)) - dnorm(nu[k], mu0, sigma0, log=T) +
          logprior_partition[K + 1] - logprior_partition[K] +
          log(d_g) + log(sum(S_g >= 2)) + log(2^(S_g[k]) - 2) - log(b_g) - log(K + 1 - 1) - log(2) -  dnorm(u,mean=0,sd=tau,log=T) +
          log(2)
      }
    }
    if (log(runif(1)) < logprob_accept) {
      g <- unlist(lapply(1:J, function(j) {
        which(sort(nu_new) == nu_new[g_new][j])
      }))
      nu <- sort(nu_new)
      K <- K_new
      if (any(nu_new[g_new] != nu[g])) {
        stop("Indexing error in death procedure. Check highest-level function inputs and re-run MCMC chain.")
      }
    }
  } else {
    ## Death!
    if (K == 1) {
      logprob_accept <- -Inf
    }else {
      if (K == 2) {
        which_merge <- c(1, 2)
      }else {
        which_merge <- sample(1:(K - 1), 1)
        which_merge <- c(which_merge, which_merge + 1)
      }
      nu_new <- nu
      nu_new[which_merge[1]] <- mean(nu[which_merge])
      nu_new[which_merge[2]] <- NA
      g_new <- g
      g_new[g_new == which_merge[2]] <- which_merge[1]
      u <- (nu[which_merge[2]]-nu[which_merge[1]])/2
      S_gnew <- unlist(lapply(1:max(g_new), function(k) {
        sum(g_new == k)
      }))
      K_new <- K-1
      logprob_accept <-
        sum(unlist(lapply(1:J,function(j){dnorm(mu_hat[j], mean = nu_new[g_new[j]], sd = s[j],log=T)}))) -
        sum(unlist(lapply(1:J,function(j){dnorm(mu_hat[j], mean = nu[g[j]], sd = s[j],log=T)}))) +
        dnorm(nu_new[which_merge[1]], mu0, sigma0, log=T) -
        sum(dnorm(nu[which_merge], mu0, sigma0, log=T)) +
        logprior_partition[K - 1] - logprior_partition[K] +
        log(b_g) + log(K-1) + log(2) + dnorm(u,mean=0,sd=tau,log=T) - log(d_g) - log(sum(S_gnew >= 2)) - log(2^(S_gnew[which_merge[1]]) - 2) +
        log(1/2)
    }
    if (log(runif(1)) < logprob_accept) {
      g_new <- as.numeric(as.factor(g_new))
      nu_new <- c(na.exclude(nu_new))
      g <- unlist(lapply(1:J, function(j) {
        which(sort(nu_new) == nu_new[g_new][j])
      }))
      nu <- sort(nu_new)
      K <- K_new
      if (any(nu_new[g_new] != nu[g])) {
        stop("Indexing error in death procedure. Check highest-level function inputs and re-run MCMC chain.")
      }
    }
  }
  g
  return(list(g = g, nu = nu, K = K))
}

#' Calculate SUCRA and MNBT based on MCMC draws in NMA or RaCE-NMA models
#'
#' This function creates a results table of SUCRA and Median Number of Better Treatments (MNBT) based on
#' MCMC draws from a standard NMA model or a fitted RaCE-NMA model.
#'
#' @import dplyr
#'
#' @param data A NxJ matrix of data, where N is the number of observations and J the number of treatments. This feature is designed to display results from a standard NMA study.
#' @param mcmc MCMC draws from the RaCE NMA model, in the form of the model output of the \code{mcmc_RCMVN} function.
#' @param level The \code{level} level for the interval estimate of MNBT. Defaults to 0.50.
#' @param names A vector of intervention names (optional)
#' @return A table containing SUCRA and MNBT values for each treatment, ordered by descending SUCRA values.
#'
#' @examples
#' mcmc <- mcmc_raceNMA(mu_hat=c(0,0,1,1), s=c(.1,.1,.1,.1), seed=1)
#' calculate_SUCRA_MNBT(mcmc=mcmc)
#' @export
calculate_SUCRA_MNBT <- function(data=NULL,mcmc=NULL,level=0.50,names=NULL){
  if(!is.null(data)){
    J <- ncol(data)
    if(is.null(names)){
      names <- paste(1:J)
    }
    data_ranks <- as.data.frame(t(apply(data,1,function(mu){rank(mu,ties.method="min")})))
    data_ranks_probs <- apply(data_ranks,2,function(ranks){sapply(1:J,function(j){mean(ranks==j)})})
    data_ranks_probs_cumulative <- apply(data_ranks_probs,2,cumsum)


    SUCRA = apply(data_ranks_probs_cumulative[1:(J-1),],2,mean)
    MNBT = apply(data_ranks,2,function(ranks){
      values <- quantile(ranks-1,c(0.5,(1-level)/2,1-(1-level)/2))
      paste0(values[1]," (",values[2],", ",values[3],")")
    })
    result <- data.frame(Treatment=names,SUCRA=SUCRA,MNBT=MNBT) %>% arrange(desc(SUCRA),row.names=FALSE)
    rownames(result) <- NULL
    names(result)[3] <- paste0("MNBT (",level*100,"% CI)")
  }
  if(!is.null(mcmc)){
    mcmc_mu <- mcmc[,grep("mu",names(mcmc))]
    J <- ncol(mcmc_mu)
    if(is.null(names)){
      names <- paste(1:J)
    }
    mcmc_ranks <- as.data.frame(t(apply(mcmc_mu,1,function(mu){rank(mu,ties.method="min")})))
    mcmc_ranks_probs <- apply(mcmc_ranks,2,function(ranks){sapply(1:J,function(j){mean(ranks==j)})})
    mcmc_ranks_probs_cumulative <- apply(mcmc_ranks_probs,2,cumsum)


    SUCRA = apply(mcmc_ranks_probs_cumulative[1:(J-1),],2,mean)
    MNBT = apply(mcmc_ranks,2,function(ranks){
      values <- quantile(ranks-1,c(0.5,(1-level)/2,1-(1-level)/2))
      paste0(values[1]," (",values[2],", ",values[3],")")
    })
    result <- data.frame(Treatment=names,SUCRA=SUCRA,MNBT=MNBT) %>% arrange(desc(SUCRA),row.names=FALSE)
    rownames(result) <- NULL
    names(result)[3] <- paste0("MNBT (",level*100,"% CI)")
  }
  return(result)
}

#' Posterior relative treatment effects for non-baseline treatments based on Wang et. al (2022)
#'
#' The dataset includes relative treatment effects for 10 non-baseline treatments across 60k posterior
#' draws based on an NMA study by Wang et. al (2022).
#'
#' @format data.frame in which the (i,j) entry is the relative treatment effect of treatment j in posterior draw i.
"wang_posterior"

#' Create trace plots for the mu parameter in RaCE NMA models
#'
#' This function creates trace plots for the mu parameter in the form of a ggplot.
#'
#' @importFrom magrittr %>%
#' @importFrom dplyr select
#' @import utils
#'
#' @param mcmc MCMC draws from the RaCE NMA model, in the form of the model output of the \code{mcmc_RCMVN} function.
#' @param names A vector of intervention names (optional)
#'
#' @return A ggplot of trace plots for the mu parameter.
#'
#' @examples
#' mcmc <- mcmc_raceNMA(mu_hat=c(0,0,1,1), s=c(.1,.1,.1,.1), seed=1)
#' traceplot_mu(mcmc,names=paste0("Treatment ",1:4))
#' @export
traceplot_mu <- function(mcmc,names=NULL){
  J <- (ncol(mcmc)-3)/3
  mu_posterior <- mcmc[,c("chain","iteration",paste0("mu",1:J))]
  if(is.null(names)){
    names(mu_posterior)[3:ncol(mu_posterior)] <- paste0("Treatment ",1:J)
  }else{
    names(mu_posterior)[3:ncol(mu_posterior)] <- names
  }
  mu_posterior <- melt(mu_posterior,id.vars = 1:2)
  g <- ggplot(data=mu_posterior,aes(x=iteration,y=value,color=chain))+
    geom_line()+facet_wrap(~variable,scales = "free_y")+theme_minimal()+
    theme(panel.grid.minor = element_blank(),panel.grid.major.x = element_blank())+
    labs(x="Iteration",y=expression("Posterior of"~mu),color="Chain")
  return(g)
}

#' Toy data of posterior relative treatment effects
#'
#' The dataset includes relative treatment effects for 4 treatments across 10k posterior
#' draws, as studied in Simulation Study 2 of Pearce and Zhou (2025).
#'
#' @format data.frame in which the (i,j) entry is the relative treatment effect of treatment j in posterior draw i.
"toy_data"

#' Create a cumulative ranking plot in RaCE NMA models
#'
#' This function creates a cumulative ranking plot in the form of a ggplot.
#'
#' @import ggplot2
#'
#' @param data A NxJ matrix of data, where N is the number of observations and J the number of treatments. This feature is designed to display results from a standard NMA study.
#' @param mcmc MCMC draws from the RaCE NMA model, in the form of the model output of the \code{mcmc_RCMVN} function.
#' @param names A vector of intervention names (optional)
#'
#' @return A ggplot of a cumulative ranking plot.
#'
#' @examples
#' mcmc <- mcmc_raceNMA(mu_hat=c(0,0,1,1), s=c(.1,.1,.1,.1), seed=1)
#' cumulativeprobplot_ranks(mcmc=mcmc,names=paste0("Treatment ",1:4))
#' @export
cumulativeprobplot_ranks <- function(data=NULL, mcmc=NULL, names=NULL){
  if(!is.null(data)){
    J <- ncol(data)
    if(is.null(names)){
      names <- paste(1:J)
    }
    data_ranks <- as.data.frame(t(apply(data,1,function(mu){rank(mu,ties.method="min")})))
    names(data_ranks) <- names
    data_meanorder <- order(apply(data_ranks,2,mean))
    data_rank_cumulative_probability <- melt(apply(data_ranks,2,function(ranks){
      unlist(lapply(1:J,function(j){mean(ranks<=j)}))}))

    g <- ggplot(data_rank_cumulative_probability,aes(x=Var1,y=value,group=Var2,color=Var2))+
      geom_line()+theme_minimal()+
      scale_x_continuous(breaks=1:J)+
      theme(panel.grid.minor = element_blank(),panel.grid.major.x = element_blank())+
      labs(x="Posterior Rank",y="Cumulative Probability",color=NULL)
  }
  if(!is.null(mcmc)){
    J <- (ncol(mcmc)-3)/3
    posterior_mu <- mcmc[,grep("mu",names(mcmc))]
    posterior_ranks <- t(apply(posterior_mu,1,function(mu){rank(mu,ties.method = "min")}))
    posterior_meanorder <- order(apply(posterior_ranks,2,mean))
    posterior_rank_cumulative_probability <- melt(apply(posterior_ranks,2,function(ranks){
      unlist(lapply(1:J,function(j){mean(ranks<=j)}))}))
    if(is.null(names)){
      posterior_rank_cumulative_probability$Var2 <- factor(posterior_rank_cumulative_probability$Var2,
                                                           levels=paste0("mu",posterior_meanorder),
                                                           labels=paste0("Treatment ",posterior_meanorder))
    }else{
      posterior_rank_cumulative_probability$Var2 <- factor(posterior_rank_cumulative_probability$Var2,
                                                           levels=paste0("mu",posterior_meanorder),
                                                           labels=names[posterior_meanorder])
    }
    g <- ggplot(posterior_rank_cumulative_probability,aes(x=Var1,y=value,group=Var2,color=Var2))+
      geom_line()+theme_minimal()+
      scale_x_continuous(breaks=1:J)+
      theme(panel.grid.minor = element_blank(),panel.grid.major.x = element_blank())+
      labs(x="Posterior Rank (clustered)",y="Cumulative Probability",color=NULL)
  }
  return(g)
}

#' Fit a Bayesian Rank-Clustered Estimation model for Network Meta-Analysis (RaCE-NMA). Recommended for internal use only; use mcmc_RCMVN instead.
#'
#' This function fits a Bayesian RaCE-NMA model to data from a previous network meta-analysis.
#'
#' @import invgamma
#' @import mvtnorm
#' @import reshape2
#' @importFrom stats dnorm
#' @importFrom stats na.exclude
#' @importFrom stats quantile
#' @importFrom stats rbinom
#' @importFrom stats rnorm
#' @importFrom stats runif
#' @importFrom stats var
#'
#'
#' @param posterior A matrix of posterior draws of relative intervention effects based on a previous NMA. The (i,j) is the ith draw of the effect of intervention j.
#' @param mu_hat A vector of estimated average relative intervention effects based on a previous NMA. The jth entry is the effect of intervention j. Ignored if \code{posterior} is supplied.
#' @param cov A variance covariance matrix of relative intervention effects based on a previous NMA. The (i,j) entry is the covariane between intervention i and j's effects. Ignored if \code{posterior} is supplied.
#' @param s A vector of the estimated standard deviations of each intervention. The jth entry is the standard deviation of intervention j. Ignored if \code{posterior} is supplied.
#' @param mu0 The hyperparameter mu0. If \code{NULL}, set to mean(mu_hat).
#' @param sigma0 The hyperparameter sigma_0. If \code{NULL}, set to sqrt(10*var(mu_hat)) which aims to be minimally informative.
#' @param tau The standard deviation of the Metropolis Hastings proposal distribution. If \code{NULL}, set to min(|mu_hat_i-mu_hat_j|).
#' @param nu0 A numeric vector for the initialization of worth parameters, mu, in the MCMC algorithm. Default to \code{NULL}, indicating random initialization.
#' @param iter A numeric indicating the total number of outer MCMC iterations (i.e., the number of times the partition is updated in the Gibbs sampler).
#' @param nu_iter A numeric indicating the number of times each worth parameter is drawn per update of the parameter partition. There will be a total of \code{iter}x\code{nu_iter} samples from the posterior.
#' @return A list of 4 elements: \code{mu}, a (\code{iter}x\code{nu_iter})x\code{J} matrix of approximate posterior draws of the intervention-specific worth parameters, mu; \code{nu} a (\code{iter}x\code{nu_iter})x\code{J} matrix of the unique parameter values corresponding to the jth partition cluster in posterior draw i, \code{g} a a (\code{iter}x\code{nu_iter})x\code{J} matrix indicating the cluster membership of object j in posterior draw i, and \code{K} a vector of the number of non-empty partition clusters in each posterior draw.
#'
#' @examples
#' fit_raceNMA(mu_hat=c(0,0,1,1), s=c(.1,.1,.1,.1), mu0=0.5, sigma0=5, tau=0.5,
#'           nu0 = NULL, iter = 5000, nu_iter = 2)
#' @export
fit_raceNMA <-  function(posterior=NULL, mu_hat=NULL, cov=NULL, s=NULL, mu0=NULL, sigma0=NULL, tau, nu0, iter, nu_iter){

  ## Checks to ensure appropriate data provided
  if(!is.null(posterior)){
    corr <- TRUE
    if(!is.null(mu_hat)){
      rm(mu_hat)
      warning("Since `posterior` provided, ignoring mu_hat")
    }
    if(!is.null(s)){
      rm(s)
      warning("Since `posterior` provided, ignoring s")
    }
    if(!is.null(cov)){
      rm(cov)
      warning("Since `posterior` provided, ignoring cov")
    }
    mu_hat <- apply(posterior,2,mean)
    cov <- cov(posterior)
  }else{
    if(is.null(mu_hat)){stop("If posterior samples are not provided, must supply mu_hat")}
    if(!is.null(cov)){
      corr <- TRUE
      if(!is.null(s)){
        rm(s)
        warning("Since `posterior` provided, ignoring s")}
    }else{
      corr <- FALSE
      if(is.null(s)){stop("If posterior samples and cov are not provided, must supply s")}
      if(!is.null(cov)){
        rm(cov)
        warning("Since `posterior` provided, ignoring cov")
      }
    }
  }
  J <- length(mu_hat)
  if(corr){
    if(nrow(cov)!=J){stop("length(mu_hat) must equal nrow(cov)")}
  }else{
    if(length(s)!=J){stop("mu_hat and s must be of the same length")}
  }

  if(is.null(mu0)){mu0 <- mean(mu_hat)}
  if(is.null(sigma0)){sigma0 <- sqrt(10*var(mu_hat))}

  nu_samples <- matrix(NA, nrow = iter * nu_iter, ncol = J)
  g_samples <- matrix(NA, nrow = 0, ncol = J)
  K_samples <- c()
  curr <- 1
  if (is.null(tau)){
    tau <- 0.5*max(abs(diff(sort(mu_hat))))
  }
  if (is.null(nu0)) {
    if(corr){
      nu <- rnorm(J,mean=mu_hat,sd=tau)
    }else{
      nu <- rnorm(J,mean=mu_hat,sd=tau)
    }
    g <- 1:J
    K <- J
  }else {
    g <- as.numeric(factor(nu0))
    K <- length(unique(g))
    nu <- as.numeric(levels(factor(nu0)))
  }

  for (it in 1:iter) {
    ## Update partitions, g (and correspondingly, K)
    if(corr){
      g_curr <- sample_partition_correlation(mu_hat=mu_hat, J=J, nu=nu, g=g, K=K, mu0=mu0,
                                             sigma0=sigma0, cov=cov, tau=tau)
      g <- g_curr$g
      nu<- g_curr$nu
      K <- g_curr$K
    }else{
      g_curr <- sample_partition_independence(mu_hat=mu_hat, J=J, nu=nu, g=g, K=K, mu0=mu0,
                                              sigma0=sigma0, s=s, tau=tau)
      g <- g_curr$g
      K <- g_curr$K
    }

    ## Update nu
    nu_curr <- matrix(data = NA, nrow = nu_iter, ncol = K)
    if(corr){
      for(nu_it in 1:nu_iter){
        for(k in 1:K){
          nu_prop <- nu
          nu_prop[k] <- nu[k]+rnorm(1,mean=0,sd=tau)
          logtransition_prob <- (dmvnorm(mu_hat,mean=nu_prop[g],sigma=cov,log=T)+dnorm(nu_prop[k],mu0,sigma0,log=T))-
            (dmvnorm(mu_hat,mean=nu[g],sigma=cov,log=T)+dnorm(nu[k],mu0,sigma0,log=T))
          if(logtransition_prob > log(runif(1))){
            nu[k] <- nu_prop[k]
          }
        }
        nu_curr[nu_it,] <- nu
      }
    }else{
      for(k in 1:K){
        C_k <- which(g==k)
        precision <- sum(c(1/sigma0^2,1/s[C_k]^2))
        post_mean <- sum(c(mu0/sigma0^2,mu_hat[C_k]/s[C_k]^2))/precision
        post_sd <- sqrt(1/precision)
        nu_curr[,k] <- rnorm(nu_iter,mean=post_mean,sd=post_sd)
      }
      nu <- nu_curr[nu_iter,]
    }

    ## Save results; update counter
    g_samples <- rbind(g_samples, matrix(rep(g, nu_iter), ncol = J, byrow = T))
    K_samples <- c(K_samples, rep(K, nu_iter))
    nu_samples[curr:(curr + nu_iter - 1), 1:K] <- nu_curr
    curr <- curr + nu_iter
  }
  mu_samples <- matrix(sapply(1:nrow(nu_samples),function(it) {
    nu_samples[it, g_samples[it, ]]
  }), nrow = nrow(nu_samples), byrow = T)
  return(list(mu = mu_samples,
              nu = nu_samples,
              g = g_samples,
              K = K_samples))
}

#' Create trace plots for the K parameter in RaCE NMA models
#'
#' This function creates trace plots for the K parameter in the form of a ggplot.
#'
#' @importFrom magrittr %>%
#' @importFrom dplyr select
#' @import utils
#'
#' @param mcmc MCMC draws from the RaCE NMA model, in the form of the model output of the \code{mcmc_RCMVN} function.
#'
#' @return A ggplot of trace plots for the K parameter.
#'
#' @examples
#' mcmc <- mcmc_raceNMA(mu_hat=c(0,0,1,1), s=c(.1,.1,.1,.1), seed=1)
#' traceplot_K(mcmc)
#' @export
traceplot_K <- function(mcmc){
  g <- ggplot(data=mcmc,aes(x=iteration,y=K,color=chain))+
    geom_line()+theme_minimal()+
    theme(panel.grid.minor = element_blank(),panel.grid.major.x = element_blank())+
    labs(x="Iteration",y="Posterior of K",color="Chain")
  return(g)
}

#' Create a posterior clustering matrix for the interventions based on RaCE NMA models
#'
#' This function creates a posterior clustering matrix for the interventions in the form of a ggplot.
#'
#' @import ggplot2
#' @importFrom magrittr %>%
#' @importFrom dplyr filter
#'
#' @param data A NxJ matrix of data, where N is the number of observations and J the number of treatments. This feature is designed to display results from a standard NMA study.
#' @param mcmc MCMC draws from the RaCE NMA model, in the form of the model output of the \code{mcmc_RCMVN} function.
#' @param names A vector of intervention names (optional)
#' @param label_ranks A vector containing rank levels for which posterior rank probabilities should be displayed within the clustering matrix. Only non-zero probabilities are displayed. Defaults to \code{NULL}, indicating no probabilities are displayed as text.
#'
#' @return A ggplot of a posterior clustering matrix for the interventions.
#'
#' @examples
#' data("toy_data")
#' mcmc <- mcmc_raceNMA(posterior=toy_data,iter=500,nu_iter=2,chains=1)
#' clusterplot_ranks(mcmc=mcmc,names=paste0("Treatment ",1:10),label_ranks=1:3)
#' @export
clusterplot_ranks <- function(data=NULL,mcmc=NULL,names=NULL,label_ranks=NULL){
  if(!is.null(data)){
    J <- ncol(data)
    if(is.null(names)){
      names <- paste(1:J)
    }
    data_ranks <- as.data.frame(t(apply(data,1,function(mu){rank(mu,ties.method="min")})))
    data_ranks_probs <- as.data.frame(apply(data_ranks,2,function(ranks){sapply(1:J,function(j){mean(ranks==j)})}))
    names(data_ranks_probs) <- names

    g <- ggplot(melt(cbind(rank=1:J,data_ranks_probs),id.vars = 1),
           aes(x=rank,y=factor(variable,levels=names[order(apply(data,2,mean))]),fill=value))+
      geom_tile()+scale_x_continuous(breaks=1:J,limits=c(0.5,J+0.5))+
      scale_y_discrete(limits=rev)+
      scale_fill_gradient(low="white",high="black",limits=c(0,1))+
      labs(x="Posterior Rank (clustered)",y=NULL,fill="Probability ")+
      theme_minimal()+theme(panel.grid = element_blank(),legend.position = "right")
    if(!is.null(label_ranks)){
      rank_data <- melt(as.matrix(data_ranks_probs)) %>%
        filter(Var1 %in% label_ranks) %>%
        filter(round(value,2)>0)
      g<- g + geom_text(data=rank_data,
                        aes(x=Var1,y=Var2,label=round(value,2)),
                        color=ifelse(rank_data$value>0.5,"white","black"))
    }
  }
  if(!is.null(mcmc)){
    J <- (ncol(mcmc)-3)/3
    posterior_mu <- mcmc[,grep("mu",names(mcmc))]
    posterior_ranks <- t(apply(posterior_mu,1,function(mu){rank(mu,ties.method = "min")}))
    posterior_meanorder <- order(apply(posterior_ranks,2,mean))
    posterior_rank_probability <- melt(apply(posterior_ranks,2,function(ranks){
      sapply(1:J,function(j){mean(ranks==j)})
    }))
    if(is.null(names)){
      posterior_rank_probability$Var2 <- factor(posterior_rank_probability$Var2,
                                                levels=paste0("mu",posterior_meanorder),
                                                labels=paste0("Treatment ",posterior_meanorder))
    }else{
      posterior_rank_probability$Var2 <- factor(posterior_rank_probability$Var2,
                                                levels=paste0("mu",posterior_meanorder),
                                                labels=names[posterior_meanorder])
    }
    g<-ggplot(posterior_rank_probability,aes(x=Var1,y=Var2,fill=value))+
      geom_tile()+scale_x_continuous(breaks=1:J,limits=c(0.5,J+0.5))+
      scale_y_discrete(limits=rev)+
      scale_fill_gradient(low="white",high="black",limits=c(0,1))+
      labs(x="Posterior Rank (clustered)",y=NULL,fill="Probability ")+
      theme_minimal()+theme(panel.grid = element_blank(),legend.position = "right")
    if(!is.null(label_ranks)){
      rank_data <- posterior_rank_probability %>%
        filter(Var1 %in% label_ranks) %>%
        filter(round(value,2)>0)
      g<- g + geom_text(data=rank_data,
                        aes(x=Var1,y=Var2,label=round(value,2)),
                        color=ifelse(rank_data$value>0.5,"white","black"))
    }
  }
  return(g)
}

#' Create posterior forest plots for relative treatment effect estimates from a standard or RaCE NMA study
#'
#' This function creates posterior forest plots for relative treatment effect estimates from a standard or RaCE NMA study.
#'
#' @import ggplot2
#'
#' @param data A NxJ matrix of data to display as a forest plot, where N is the number of observations and J the number of treatments. This feature is designed for use to display a forest plot of results from a standard NMA study.
#' @param mcmc MCMC draws from the RaCE NMA model, in the form of the model output of the \code{mcmc_RCMVN} function.
#' @param names A vector of intervention names (optional)
#' @param level A numeric indicating the desired credible level to be displayed, as a proportion. Defaults to 0.95.
#' @param order_by_average A boolean indicating if plot should order treatments by their average treatment effect.
#'
#' @return A ggplot of posterior forest plots for the mu parameter.
#'
#' @examples
#' data("toy_data")
#' forestplot_muhat(data=toy_data,names=paste0("Treatment ",1:4))
#' @export
forestplot_muhat <- function(data=NULL,mcmc=NULL,names=NULL,level=0.95,order_by_average=TRUE){
  if(!is.null(data)){
    data_mean <- apply(data,2,mean)
    data_quantiles <- apply(data,2,function(mu){quantile(mu,c((1-level)/2,(1+level)/2))})
    data_summary <- as.data.frame(t(rbind(data_mean,data_quantiles)))
    names(data_summary) <- c("mean","lower_CI","upper_CI")

    if(order_by_average){
      mean_order <- order(data_mean)
    }else{
      mean_order <- 1:length(data_mean)
    }

    if(is.null(names)){
      data_summary$name <- factor(paste0(mean_order))
      g <- ggplot(data_summary,aes(y=name,x=mean,xmin=lower_CI,xmax=upper_CI))+
        geom_point()+geom_linerange()+theme_minimal()+
        scale_y_discrete(limits=rev)+
        theme(panel.grid.minor = element_blank(),panel.grid.major.x = element_blank())+
        labs(y="Treatment",x="Posterior")
    }else{
      data_summary$name <- factor(names,levels=names[mean_order])
      g <- ggplot(data_summary,aes(y=name,x=mean,xmin=lower_CI,xmax=upper_CI))+
        geom_point()+geom_linerange()+theme_minimal()+
        scale_y_discrete(limits=rev)+
        theme(panel.grid.minor = element_blank(),panel.grid.major.x = element_blank())+
        labs(y=NULL,x="Posterior")
    }
  }
  if(!is.null(mcmc)){
    posterior_mu <- mcmc[,grep("mu",names(mcmc))]
    posterior_mu_mean <- apply(posterior_mu,2,mean)
    posterior_mu_quantiles <- apply(posterior_mu,2,function(mu){
      quantile(mu,c((1-level)/2,(1+level)/2))
    })
    if(order_by_average){
      posterior_mu_order <- order(posterior_mu_mean)
    }else{
      posterior_mu_order <- 1:length(posterior_mu_mean)
    }


    posterior_mu <- as.data.frame(t(rbind(posterior_mu_mean,posterior_mu_quantiles)))
    names(posterior_mu) <- c("mean","lower_CI","upper_CI")


    if(is.null(names)){
      posterior_mu$name <- factor(paste0("mu",1:nrow(posterior_mu)),
                                  levels=paste0("mu",posterior_mu_order))
    }else{
      posterior_mu$name <- factor(names,levels=names[posterior_mu_order])
    }
    g <- ggplot(posterior_mu,aes(y=name,x=mean,xmin=lower_CI,xmax=upper_CI))+
      geom_point()+geom_linerange()+theme_minimal()+
      scale_y_discrete(limits=rev)+
      theme(panel.grid.minor = element_blank(),panel.grid.major.x = element_blank())+
      labs(y=NULL,x="Relative Treatment Effect")
  }
  return(g)
}

#' Calculate Gelman Diagnostics for Fitted RaCE NMA Models
#'
#' This function applies MCMC outputs from the mcmc_RCMVN package to the gelman.diag function in the coda package.
#'
#' @import coda
#'
#' @param mcmc MCMC draws from the RaCE NMA model, in the form of the model output of the \code{mcmc_RCMVN} function.
#' @param names A vector of intervention names (optional)
#' @param level The \code{level} parameter from the \code{gelman.diag} function in the \code{coda} package. Defaults to 0.95.
#' @param multivariate The \code{multivariate} parameter from the \code{gelman.diag} function in the \code{coda} package. Defaults to FALSE.
#'
#' @return Gelman diagnostics for the inputted MCMC chains, in the format of the output of the \code{gelman.diag} function in the \code{coda} package.
#'
#' @examples
#' mcmc <- mcmc_raceNMA(mu_hat=c(0,0,1,1), s=c(.1,.1,.1,.1), seed=1)
#' calculate_Rhat(mcmc,names=paste0("Treatment ",1:4))
#' @export
calculate_Rhat <- function(mcmc,names=NULL,level=0.95,multivariate=FALSE){
  start_iter <- min(mcmc$iteration)
  end_iter <- max(mcmc$iteration)
  thin <- diff(mcmc$iteration[1:2])
  mcmc_list <- list()
  for(chain_iter in 1:max(as.numeric(mcmc$chain))){
    tmp <- mcmc[as.numeric(mcmc$chain)==chain_iter,c(grep("mu",names(mcmc)))]
    if(!is.null(names)){names(tmp) <- names}
    mcmc_list[[chain_iter]] <- as.mcmc(tmp,start=start_iter,end=end_iter,thin=thin)
  }
  mcmc_list <- as.mcmc.list(mcmc_list)
  return(gelman.diag(mcmc_list,confidence=level,multivariate=multivariate))
}

#' Fit a Bayesian Rank-Clustered Estimation model for Network Meta-Analysis (RaCE-NMA) using multiple MCMC chains
#'
#' This function fits a Bayesian RaCE-NMA model to data from a previous network meta-analysis. The function has input parameters to permit drawing multiple MCMC chains, as well as chain thinning and burn-in.
#'
#' @importFrom magrittr %>%
#' @importFrom dplyr select
#' @import utils
#'
#' @param posterior A matrix of posterior draws of relative intervention effects based on a previous NMA. The (i,j) is the ith draw of the effect of intervention j.
#' @param mu_hat A vector of estimated average relative intervention effects based on a previous NMA. The jth entry is the effect of intervention j. Ignored if \code{posterior} is supplied.
#' @param cov A variance covariance matrix of relative intervention effects based on a previous NMA. The (i,j) entry is the covariane between intervention i and j's effects. Ignored if \code{posterior} is supplied.
#' @param s A vector of the estimated standard deviations of each intervention. The jth entry is the standard deviation of intervention j. Ignored if \code{posterior} is supplied.
#' @param mu0 The hyperparameter mu0. If \code{NULL}, set to mean(mu_hat).
#' @param sigma0 The hyperparameter sigma_0. If \code{NULL}, set to sqrt(10*var(mu_hat)) which aims to be minimally informative.
#' @param tau The standard deviation of the Metropolis Hastings proposal distribution. If \code{NULL}, set to min(|mu_hat_i-mu_hat_j|).
#' @param nu0 A numeric vector for the initialization of worth parameters, mu, in the MCMC algorithm. Default to \code{NULL}, indicating random initialization.
#' @param iter A numeric indicating the total number of outer MCMC iterations (i.e., the number of times the partition is updated in the Gibbs sampler).
#' @param nu_iter A numeric indicating the number of times each worth parameter is drawn per update of the parameter partition. There will be a total of \code{iter}x\code{nu_iter} samples from the posterior.
#' @param chains A numeric indicating the total number of independent MCMC chains to be run.
#' @param burn_prop A numeric between 0 and 1 indicating the proportion of MCMC samples in each chain to be removed as burn-in.
#' @param thin A numeric indicating that only every \code{thin}-th sample should be retained, to save computational memory.
#' @param seed A numeric indicating the random seed that should be set before running the first MCMC chain.
#' @param verbose A boolean indicating if the function should print progress updates as the MCMC chains run. Default to \code{TRUE}.
#'
#' @return A (\code{chains}x\code{iter}/\code{thin})x(3J+3) matrix of posterior draws, one row per posterior sample of mu, nu, and g, with additional columns indicating the MCMC chain index, iteration index, and number of non-empty partition clusters K of each posterior sample.
#'
#' @examples
#' mcmc <- mcmc_raceNMA(mu_hat=c(0,0,1,1), s=c(.1,.1,.1,.1), seed=1)
#' head(mcmc)
#' @export
mcmc_raceNMA <- function(posterior = NULL, mu_hat = NULL, cov = NULL, s = NULL, mu0 = NULL, sigma0 = NULL, tau = NULL, nu0 = NULL,
                       iter = 4000, nu_iter = 5, chains = 2, burn_prop = 0.5, thin = 1, seed = NULL, verbose = TRUE){

  if(!is.null(posterior)){
    J <- ncol(posterior)
  }else{
    J <- length(mu_hat)
  }

  if (!is.null(seed)) {set.seed(seed)}
  counter <- 1
  mcmc <- replicate(n = chains,{
    if(verbose){print(paste0("Estimating chain ", counter, " of ", chains,"."))}
    counter <<- counter + 1
    res <- fit_raceNMA(posterior=posterior, mu_hat=mu_hat, cov=cov, s=s, mu0 = mu0, sigma0 = sigma0,
                     tau = tau, nu0 = nu0, iter = iter, nu_iter = nu_iter)
    nreps <- nrow(res$mu)
    keep_reps <- seq(ceiling(burn_prop * nreps) + 1, nreps,by = thin)
    tmp <- as.data.frame(cbind(res$mu[keep_reps, , drop=FALSE], res$nu[keep_reps, ,drop=FALSE],
                               res$g[keep_reps, ,drop=FALSE],res$K[keep_reps], keep_reps))
    names(tmp) <- c(paste0("mu", 1:J), paste0("nu", 1:ncol(res$nu)), paste0("G", 1:J), "K", "iteration")
    return(tmp)
  }, simplify = FALSE)
  mcmc <- do.call(rbind, mcmc)
  mcmc$chain <- factor(rep(1:chains, each = nrow(mcmc)/chains))
  mcmc <- mcmc %>% dplyr::select(chain, iteration, K, dplyr::everything())
  rm(counter)
  return(mcmc)
}

---
title: "Reproducibility"
output:
  rmarkdown::html_document:
    toc: true
    toc_depth: 3
    toc_float: true  
number_sections: true  
vignette: >
  %\VignetteIndexEntry{reproducibility}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  warning = FALSE,
  eval=FALSE
)
```

```{r warning=FALSE, message=FALSE}
library(RaCE.NMA)
library(ggplot2)
library(dplyr)
library(cowplot)
library(gridExtra)
library(reshape2)
```

In this vignette, we provide code to reproduce the analyses presented in the paper associated with this R package. Specifically, we reproduce two simulation studies (Sections 3.1 and 3.2) and a case study (Section 4). We assume knowledge of the associated R package functions; please refer to the "Tutorial" and "Reference" pages for more information. No figures are produced; see paper.

## Reproduction of Simulation Study 1 (Section 3.1)

The following code reproduces Figure 1.

```{r fig.asp=0.35}
s <- 0.1
g1a<-ggplot()+scale_x_continuous(limits=c(-3*s,1+3*s))+
  stat_function(fun = dnorm, args = list(mean = 0, sd =s))+
  stat_function(fun = dnorm, args = list(mean = 1, sd =s))+
  theme_bw()+labs(x=" ",y="Density",subtitle=expression(hat(sigma)~"=0.1"))+
  theme(panel.grid.minor = element_blank(),panel.grid.major.y = element_blank())
s <- 0.3
g1b<-ggplot()+scale_x_continuous(limits=c(-3*s,1+3*s))+
  stat_function(fun = dnorm, args = list(mean = 0, sd =s))+
  stat_function(fun = dnorm, args = list(mean = 1, sd =s))+
  theme_bw()+labs(x="Posterior Intervention Effects",y=NULL,subtitle=expression(hat(sigma)~"=0.3"))+
  theme(panel.grid.minor = element_blank(),panel.grid.major.y = element_blank())
s <- 0.5
g1c<-ggplot()+scale_x_continuous(limits=c(-3*s,1+3*s))+
  stat_function(fun = dnorm, args = list(mean = 0, sd =s))+
  stat_function(fun = dnorm, args = list(mean = 1, sd =s))+
  theme_bw()+labs(x=" ",y=NULL,subtitle=expression(hat(sigma)~"=0.5"))+
  theme(panel.grid.minor = element_blank(),panel.grid.major.y = element_blank())
grid.arrange(g1a,g1b,g1c,nrow=1)
```

The following code reproduces Figure 2: First, we perform a simulation study. Second, we create the figure.

```{r cache=TRUE}
## Perform simulation study
set.seed(1)
results <- matrix(NA,nrow=0,ncol=6)
for(iter in 1:20){
  for(J in c(6,12,18)){
    for(K in c(J/3,2*J/3,J)){
      for(s in c(0.1,0.3,0.5)){
        if(K==J){
          mu_hat <- 1:K
        }else{
          mu_hat <- sample(1:K,J,replace=T)
          while(length(unique(mu_hat))<K){mu_hat <- sample(1:K,J,replace=T)}
        }
        
        mcmc <- mcmc_raceNMA(mu_hat = mu_hat,s=rep(s,J),mu=mean(mu_hat),
                             sigma0=max(1,4*sd(mu_hat)),nu0=mu_hat,
                             tau=1,iter=3000,nu_iter=2,chains=4,
                             burn_prop=0.5,thin=3,verbose = FALSE)
        
        equal <- posterior_equal <- matrix(NA,nrow=J,ncol=J)
        for(i in 1:(J-1)){for(j in (i+1):J){
          equal[i,j] <- ifelse(mu_hat[i]==mu_hat[j],1,0) # test if treatments are truly equal in mean
          posterior_equal[i,j] <- mean( # assess if treatments are rank-clustered
            mcmc[,paste0("G",i)] == mcmc[,paste0("G",j)]
            ) 
        }}
        
        results <- rbind(
          results,
          c(iter,J,K,s,
            mean(posterior_equal[equal==1],na.rm=T),
            mean(posterior_equal[equal==0],na.rm=T))
        )
      }
    }
  }
}
```
```{r}
## Plotting results from simulation study
results <- as.data.frame(results)
names(results) <- c("Iteration","J","K","s","Prob_Clustered","Prob_Distinct")
results$s<-factor(results$s, levels=c(.1,.3,.5),
                  labels=c(expression(hat(sigma)~"=0.1"),
                           expression(hat(sigma)~"=0.3"),
                           expression(hat(sigma)~"=0.5")))
results$J <- factor(results$J,levels=c(6,12,18),
                    labels=c(expression(J~"= 6"),
                             expression(J~"= 12"),
                             expression(J~"= 18")))
results_melt <- melt(results,id.vars=1:4)
results_melt <- results_melt[!is.nan(results_melt$value),] # drop "cluster" cases when K=J
ggplot(results_melt,aes(x=factor(K),y=value,
                        color=factor(variable,labels=c("Rank-Clustered","Distinct"))))+
  facet_grid(s~J,scales="free_x",labeller=label_parsed)+
  geom_boxplot(outlier.alpha=0.5,position="identity")+theme_bw()+
  scale_color_manual(values=c("skyblue","darkblue"))+
  labs(x="Number of Rank-Clusters, K",
       y="Posterior Rank-Clustering Probability",
       color=NULL)+
  theme(legend.position = "bottom",
        panel.grid.minor = element_blank(),
        panel.grid.major.x = element_blank())
```

## Reproduction of Simulation Study 2 (Section 3.2)

The following code reproduces Figure 3.

```{r fig.asp = 0.4}
J <- 4
mu_hat <- c(-1,0,1,0)
s <- c(.1,.1,.1,1)

set.seed(2)
data <- matrix(data = rnorm(10000*4,mean=mu_hat,sd=s), ncol = 4, byrow = TRUE)

forestplot_muhat(data = data, order_by_average = FALSE)
```

The following code reproduces Table 1: First, we fit the RaCE model to the simulated data. Second, we calculate and display the values in Table 1.

```{r cache=TRUE}
mcmc <- mcmc_raceNMA(mu_hat = mu_hat, s = s, 
                   iter = 50000, nu_iter = 2, chains = 4, 
                   burn_prop = 0.5,thin = 1,verbose = FALSE)

posterior_equal <- matrix(NA,nrow=J,ncol=J)
for(i in 1:(J-1)){for(j in (i+1):J){
  posterior_equal[i,j] <- mean(mcmc[,paste0("G",i)] == mcmc[,paste0("G",j)])
}}
round(posterior_equal,2)
```
The following code reproduces Figure 4: First, we calculate the posterior rank-clustering probability under a traditional model (i.e., assumption of distinct ranks). Second, we calculate the posterior rank-clustering probability based on the RaCE model. Third, we produce the figure.

```{r fig.asp-0.6}
wang_ranks <- t(apply(data,1,function(mu){rank(mu)}))
wang_ranks_probs <- apply(wang_ranks,2,function(rank){
  sapply(1:J,function(j){mean(rank==j)})
})
race_ranks <- t(apply( mcmc[,paste0("mu",1:J)], 1, function(mu){
  rank(mu,ties.method="min")
}))
race_ranks_probs <- apply(race_ranks,2,function(rank){
  sapply(1:J,function(j){mean(rank==j)})
})

g4a<-ggplot(melt(wang_ranks_probs),
            aes(x=Var1,y=factor(Var2),fill=value)) +
  geom_tile() + theme_minimal() +
  scale_y_discrete(limits=rev) +
  scale_x_continuous(breaks=1:4,limits=c(.5,4.5)) +
  scale_fill_gradient(low="white",high="black",limits=c(0,1))+
  labs(x="Rank",y="Treatment",fill="Probability")+
  theme(panel.grid = element_blank(),legend.position = "bottom")+
  geom_text(aes(x=Var1,y=factor(Var2),label=round(value,2)),
        color=ifelse(melt(wang_ranks_probs)$value>0.4,"white","black"))

g4b<-ggplot(melt(race_ranks_probs),
            aes(x=Var1,y=factor(Var2,levels=paste0("mu",1:J),
                                labels=paste0(1:J)),fill=value))+
  geom_tile() + theme_minimal() +
  scale_y_discrete(limits=rev) +
  scale_x_continuous(breaks=1:4,limits=c(.5,4.5)) +
  scale_fill_gradient(low="white",high="black",limits=c(0,1)) +
  labs(x="Rank",y="Treatment",fill="Probability")+
  theme(panel.grid = element_blank(),legend.position = "bottom")+
  geom_text(aes(x=Var1,y=factor(Var2,levels=paste0("mu",1:J),labels=paste0(1:J)),
                label=round(value,2)),
            color=ifelse(melt(race_ranks_probs)$value>0.4,"white","black"))

plot_grid(plot_grid(g4a+theme(legend.position = "none"), 
                    g4b+theme(legend.position = "none"), 
                    labels = c('A', 'B'), label_size = 12),
          get_plot_component(g4a, 'guide-box-bottom', return_all = TRUE),
          nrow=2,rel_heights = c(.9,.1) )
```

## Reproduction of Case Study (Section 4)

We first load the posteriors from Wang et al. (2022) and calculate the mean and covariances of the relative treatment effects.

```{r}
data("wang_posterior") # loads posterior of non-baseline treatments

# define assumed mean and variance for baseline treatment (R-CHOP)
mu_hat_baseline <- 0
var_baseline <- min(apply(wang_posterior,2,var))/10

# calculate summary statistics, mu_hat and cov, for all treatments
mu_hat <- c( mu_hat_baseline, apply(wang_posterior,2,mean) )
cov <- cbind( c(var_baseline, rep(0, 10) ),
              rbind(0, cov(wang_posterior)) )

# store treatment names
treatments <- c("R-CHOP", names(wang_posterior))
```

The following code chunk reproduces Figure 5.

```{r fig.asp = 0.4, warning=FALSE}
forestplot_muhat(data=wang_posterior,names=treatments[-1])
```

Next, we fit the RaCE model to estimated relative treatment effects from Wang et al. (2022).

```{r}
mcmc <- mcmc_raceNMA(mu_hat = mu_hat, cov = cov, 
                   mu0 = mean(mu_hat), sigma0 = sqrt(10*var(mu_hat)),
                   iter = 50000, nu_iter = 5, chains = 4, 
                   seed = 1, verbose = FALSE)
```

The following code chunk reproduces Figure 6, Figure 7, and Table 2: First, we calculate the values underpinning each graphic. Then, we create each in turn.

```{r fig.asp=0.45}
# Figure 6
g9a <- clusterplot_ranks(data=cbind(0,wang_posterior),
                            names=treatments,label_ranks=1)+
  theme(legend.position = "bottom")
g9b <- clusterplot_ranks(mcmc=mcmc,names=treatments,label_ranks = 1)
plot_grid(plot_grid(g9a+theme(legend.position = "none"), 
                    g9b+theme(legend.position = "none"), 
                    labels = c('A', 'B'), label_size = 12),
          get_plot_component(g9a, 'guide-box-bottom', return_all = TRUE),
          nrow=2,rel_heights = c(.9,.1))
# Figure 7
g10a <- cumulativeprobplot_ranks(data=cbind(0,wang_posterior),names=treatments)+
  theme(legend.position = "bottom") +
  guides(color = guide_legend(nrow = 2))
g10b <- cumulativeprobplot_ranks(mcmc=mcmc,names=treatments)
plot_grid(plot_grid(g10a+theme(legend.position = "none"), g10b+theme(legend.position = "none"), 
                        labels = c('A', 'B'), label_size = 12),
              get_plot_component(g10a, 'guide-box-bottom', return_all = TRUE),
          nrow=2,rel_heights = c(.85,.15) )
# Table 2
res_WANG <- calculate_SUCRA_MNBT(data = cbind(0,wang_posterior),
                                 level = 0.50, names = treatments)
res_RaCENMA <- calculate_SUCRA_MNBT(mcmc = mcmc, level = 0.50, names = treatments)
table2 <- left_join(res_WANG,res_RaCENMA,by="Treatment")[,c(1,2,4,3,5)]
names(table2) <- c("Treatment","SUCRA (Wang)","SUCRA (RaCE)","MNBT (Wang)","MNBT (RaCE)")
print(table2)
```

The following code chunk reproduces the Figures 8--10 (Appendix B).

```{r fig.asp=0.4}
traceplot_K(mcmc)+
  scale_x_continuous(breaks=seq(125000,250000,by=25000),
                     labels=paste0(seq(125,250,by=25),"k"))
traceplot_mu(mcmc,names=treatments)+
  scale_x_continuous(breaks=seq(125000,250000,by=25000),
                     labels=paste0(seq(125,250,by=25),"k"))
forestplot_muhat(mcmc=mcmc,names=treatments)
```

---
title: "Tutorial"
output:
  rmarkdown::html_document:
    toc: true
    toc_depth: 3
    toc_float: true  
number_sections: true  
vignette: >
  %\VignetteIndexEntry{tutorial}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  warning=FALSE,
  comment = "#>"
)
options(rmarkdown.html_vignette.check_title = FALSE)
```

# Overview

In this vignette, we provide a detailed tutorial of the key functionalities of the `RaCE.NMA` R package. The package has functions to complete three primary tasks in the analysis pipeline when utilizing the RaCE-NMA methodology:

1. Model estimation
2. Model assessment
3. Inference and summary statistics

After loading the necessary packages to run our analyses, we demonstrate each of the primary tasks in the analysis pipeline on two datasets: A toy dataset (as seen in Simulation Study 2 of the paper) and real data (as seen in the Case Study of the paper).

```{r warning=FALSE,message=FALSE}
library(RaCE.NMA)
library(reshape2) # data reformatting
library(ggplot2)  # creating nice figures
```

# Toy Data

First, we use a "toy" dataset that can be seen in Simulation Study 2 of the paper. The data is included in the `RaCE.NMA` package and can be loaded using the following code:

```{r}
data("toy_data")
head(toy_data)
```

The data contains $10{,}000$ rows and 4 columns. Each column represented a treatment, and each row a posterior draw of relative treatment effects for those treatments. We assume these posterior draws are based on a standard NMA model (i.e., no rank-clustering). 

To visualize these posterior draws, we create a forest plot (with 95\% CIs) via the aptly-named `create_forestplot` function:

```{r fig.asp=0.45, fig.cap="Figure 1: Forest plot of estimated relative treatment effects in a toy example dataset, based on a standard NMA model."}
forestplot_muhat(data = toy_data, level = 0.95, 
                  order_by_average = FALSE)
```

We observe that the first three treatments have narrow and well-separated credible intervals of relative efficacy. The fourth treatment, however, has a very wide interval to indicate high uncertainty in its relative efficacy.

Now we are ready to start the analysis pipeline.

## 1. Model Estimation

The `RaCE.NMA` packages contains a primary model-fitting function, `mcmc_RCMVN`. The function requires many inputs, which may be broken down into three categories:

  + Previous results from an NMA analysis: The user must provide results on the relative treatment effects from a previous NMA study. Various formats are allowed; see below.
  + Model hyperparameters: Parameters which correspond to "priors" in the Bayesian model. Vague priors are available by default.
  + MCMC settings: Specifications of an MCMC estimation procedure, including the number of independent chains, length of each chain, thinning and burn-in, etc. By default, the function runs 2 chains, each of length 15000 and removes the first half of iterations as burn-in.
  
### Results of a standard NMA model

If available, we recommend inputting the full posterior of the relative treatment effect from a previous NMA analysis into the `mcmc_RCMVN` function. In this case, the `posterior` argument should be provided an $N\times J$ matrix, where the (i,j) entry indicates the relative treatment effect of treatment $j$ in MCMC draw $i$. An example of this functionality is provided below:

```{r eval=FALSE}
mcmc_raceNMA(posterior = toy_data)
```

In the above code, default settings are used for all other inputs. (We recommend against this practice.)

Alternatively, one may provide summary statistics of the model posterior (instead of a full posterior itself). This is useful when applying the RaCE-NMA methodology to the results of a published paper post-hoc, when only summary statistics are available. In this setting, the user must provide two inputs:

  + `mu_hat`: A vector of length $J$ (the number of treatments), where the $j$th entry displays the average relative treatment effect of treatment $j$
  + `cov` or `s`: A $J\times J$ covariance matrix of relative treatment effects *or* a vector of length $J$ of treatment-specific standard deviations of relative treatment effects.
  
An example of this functionality is provided below:
```{r eval=TRUE}
mu_hat_toy <- apply(toy_data, 2, mean)
cov_toy <- cov(toy_data)
s_toy <- apply(toy_data, 2, sd)
```
```{r eval=FALSE}
mcmc_raceNMA(mu_hat = mu_hat_toy, cov = cov_toy) # example with mu_hat and cov
mcmc_raceNMA(mu_hat = mu_hat_toy, s   = s_toy  ) # example with mu_hat and s
```
  
If duplicative inputs are provided, the function will always use those provided the "richest" information. Specifically,

  + If `posterior` is provided, `mu_hat`, `cov`, and/or `s` will be ignored. 
  + If `cov` is provided, `s` is ignored. 


### Model hyperparameters

Next, we may specify the following hyperparameters:

  + `mu0`: The prior mean on the rank-clustered relative treatment effects. Defaults to `mean(mu_hat)`, which aims to be vague.
  + `sigma0`: The prior standard deviation on the rank-clustered relative treatment effects. Defaults to `sqrt(10*var(mu_hat))`, which aims to be vague.
  
The following code demonstrates how one could specify these hyperparameters directly in the estimation function:

```{r eval=FALSE}
mcmc_raceNMA(
  posterior = toy_data, # results of a standard NMA model
  mu0 = mean(mu_hat_toy), sigma0 = sqrt(10*var(mu_hat_toy)), # model hyperparameters
)
```

### MCMC settings

Last, we may specify parameters that control how the MCMC chains are run:

  + `tau`: The standard deviation of the Metropolis Hastings proposal distribution. Defaults to `min(|mu_hat_i-mu_hat_j|)`. 
  + `nu0`: How cluster-specific mean parameters are initialized. Defaults to `NULL`, which randomly samples from the prior distribution.
  + `iter`: The number of times the rank-clustering structure is sampled in each MCMC chain. Defaults to $4{,}000$.
  + `nu_iter`: The number of times each cluster-specific mean is sampled per sampling of the rank-clustering structure. Defaults to $5$. In total, there will be `iter`$\times$`nu_iter` samples from the posterior.
  + `chains`: The number of independent MCMC chains. Defaults to 2.
  + `burn_prop`: The proportion of MCMC samples in each chain to be removed as burn-in. Defaults to 0.5.
  + `thin`: A number indicating how often to thin samples. Defaults to 1, indicating no thinning.
  + `seed`: The random seed to run chains. Defaults to `NULL`, meaning the environment seed is inherited.

The following code demonstrates how one could specify some of these settings directly in the estimation function:

```{r}
mcmc_results_toy <- mcmc_raceNMA(
  posterior = toy_data, # results of a standard NMA model
  mu0 = mean(mu_hat_toy), sigma0 = sqrt(10*var(mu_hat_toy)), # model hyperparameters
  iter = 10000, nu_iter = 2, # MCMC settings
  chains = 2, burn_prop = 0.5, thin = 1, seed = 1
)
```

## 2. Model Assessment

The package contains three functions to assess if the MCMC chains have converged and mixed. The first two produce trace plots of `mu` and `K`, the primary model parameters. The third calculates the $\hat{R}$ statistic for each `mu` parameter. We display and interpret each plot below.

```{r, fig.cap="Figure 2: Trace plots of relative treatment effects in a toy example dataset, based on the RaCE-NMA model."}
traceplot_mu(mcmc_results_toy)
```

We observe acceptable mixing and convergence in the trace plots for $\mu$. Ideally, the two chains would like similar to each other, with each exhibiting a "white noise pattern". This is certainly true for $\mu_1$, $\mu_2$, and $\mu_3$. For $\mu_4$, we notice some "jumps" in value across iterations. Based on our toy data, in which treatment 4 has extremely high uncertainty, we expect this type of behavior. Furthermore, since the chains both exhibit similar patterns, we are satisfied.

```{r, fig.cap="Figure 3: Trace plot of the number of rank-clusters, K, in a toy example dataset, based on the RaCE-NMA model."}
traceplot_K(mcmc_results_toy)
```

We again observe acceptable mixing and convergence in the trace plot for $K$. That is, the two chains are indistinguishable and exhibit a seemingly random pattern between the values $3$ and $4$.

```{r, fig.cap="Table 1: R-hat statistics for the relative treatment effects in a toy example dataset, based on the RaCE-NMA model."}
calculate_Rhat(mcmc_results_toy, level = 0.9)
```
The $\hat{R}$ statistic is a standard convergence diagnostic statistic used to assess MCMC chains. A standard rule of thumb is to ensure that $\hat{R}<1.1$. We see that the point estimate and 90% confidence intervals for all $\mu$ parameters are $\leq1.1$, indicating acceptable convergence.

## 3. Inference and summary statistics

The package contains three functions to visualize model results. We demonstrate each in turn:

Posterior rank probabilities for each intervention. Ranks are displayed on the ordinal scale (1 = best). Interventions are grouped into rank clusters representing non-exclusive superiority sets; multiple interventions within the same cluster may share identical posterior ranks.

The first is to create a clustering probability matrix.  In the figure, each row represents a treatment and each column a rank level. The color of the corresponding cell is the estimated posterior probability that a treatment belongs to a specific rank. Note that the `label_ranks` input allows the user to specify which rank levels in the graphic are labeled with a *numerical* probability (corresponding to the color shown). See the figure and corresponding interpretation below.

```{r fig.asp=0.6, fig.cap="Figure 4: Posterior rank probabilities for each intervention in a toy example dataset, based on the RaCE-NMA model. Ranks are displayed on the ordinal scale (1 = best). Interventions are grouped into rank clusters representing non-exclusive superiority sets; multiple interventions within the same cluster may share identical posterior ranks."}
clusterplot_ranks(mcmc=mcmc_results_toy, label_ranks = 1:4)
```

The model estimates a 0.97 probability that Treatment 1 is in first place. Simultaneously, the model estimates a 0.21 probability that Treatment 4 is in first place. Thus, there is some probability, based on the model, that Treatments 1 and 4 are simultaneously the "best" treatments. That being said, Treatment 4 has substantial uncertainty in its rank, which aligns with the high uncertainty in original relative treatment effect data. Treatment 2 has a 0.72 probability of being in second place and Treatment 4 has a 0.87 probability of being in fourth (last) place.


The second function creates a cumulative ranking probability curve for each treatment. In words, the plot displays the probability that each treatment is *at least* in a specific rank place. For example, we see that Treatment 4 has a 0.80 probability of being in first or second place.

```{r fig.asp=0.4, fig.cap="Figure 5: Cumulative ranking probability curves for each intervention in a toy example dataset, based on the RaCE-NMA model."}
cumulativeprobplot_ranks(mcmc=mcmc_results_toy)
```

The third function creates a table displaying the SUCRA value and the Median Number of Better Treatments (MNBT) for each treatment (with a corresponding credible interval). The credible level may be specified using the `credible` argument.

```{r, fig.cap="Table 2: SUCRA and MNBT statistics for each intervention in a toy example dataset, based on the RaCE-NMA model."}
calculate_SUCRA_MNBT(mcmc=mcmc_results_toy, level = 0.5)
```

# Real Data (Wang et. al [2022])

Next, we demonstrate the package on a real NMA study provided by Wang et. al (2022) and analyzed as a Case Study in our paper. The data is included in the `RaCE.NMA` package and can be loaded using the following code:

```{r}
data("wang_posterior")
round(head(wang_posterior), 3)
```

It is important to note that `wang_posterior` only includes relative treatment effects for non-baseline treatments. An 11th treatment, "R-CHOP", was the baseline with a relative treatment effect of 0 by construction. Thus, for technical reasons described in the paper, we will need to define summary statistics that can be used when fitting the RaCE-NMA model.

```{r}
# define assumed mean and variance for baseline treatment (R-CHOP)
mu_hat_baseline <- 0
var_baseline <- min(apply(wang_posterior,2,var))/10

# calculate summary statistics, mu_hat and cov
mu_hat_wang <- c( mu_hat_baseline, apply(wang_posterior,2,mean) )
cov_wang <- cbind( c(var_baseline, rep(0, 10) ),
              rbind(0, cov(wang_posterior)) )

# store treatment names
treatments <- c("R-CHOP", names(wang_posterior))
```

The following forest plot displays the relative treatment effects of the 11 treatments in the study, as estimated by Wang et. al (2022).

```{r fig.asp=0.5, fig.cap="Figure 6: Forest plot of estimated relative treatment effects in a network meta-analysis by Wang et. al (2022), based on a standard NMA model."}
forestplot_muhat(data = cbind(0,wang_posterior), 
                 names = treatments)
```

Now, we proceed through the analysis pipeline.

## 1. Model Estimation

We fit the model below using 2 chains, each with $10{,}000\times 2$ MCMC iterations.

```{r cache=TRUE}
mcmc_results_casestudy <- mcmc_raceNMA(
  mu_hat = mu_hat_wang, cov = cov_wang,
  iter = 10000, nu_iter = 2, chains = 2, seed = 1
)
```

## 2. Model Assessment

Next, we view trace plots and convergence diagnostics.

```{r, fig.cap="Figure 7: Trace plots of relative treatment effects in a network meta-analysis by Wang et. al (2022), based on the RaCE-NMA model."}
traceplot_mu(mcmc_results_casestudy, names=treatments)
```
```{r, fig.cap="Figure 8: Trace plot of the number of rank-clusters, K, in a network meta-analysis by Wang et. al (2022), based on the RaCE-NMA model."}
traceplot_K(mcmc_results_casestudy)
```
```{r, fig.cap="Table 3: R-hat statistics for the relative treatment effects in a network meta-analysis by Wang et. al (2022), based on the RaCE-NMA model."}
calculate_Rhat(mcmc_results_casestudy, names=treatments)
```

We observe that chains have not run long enough (refer to the Reproducibility tab for a longer run of chains). However, for demonstration purposes we continue with the next stage of the analysis pipeline below.

## 3. Inference and summary statistics

Disclaimer: The results below are based on chains which have not converged, but are shown for demonstration purposes. Please see the Reproducibility tab for accurate results based on this data.

```{r fig.asp=0.6, fig.cap="Figure 9: Posterior rank probabilities for each intervention in a network meta-analysis by Wang et. al (2022), based on the RaCE-NMA model. Ranks are displayed on the ordinal scale (1 = best). Interventions are grouped into rank clusters representing non-exclusive superiority sets; multiple interventions within the same cluster may share identical posterior ranks."}
clusterplot_ranks(mcmc=mcmc_results_casestudy, names = treatments, label_ranks = 1)
```
```{r fig.asp=0.4, fig.cap="Figure 10: Cumulative ranking probability curves for each intervention in a network meta-analysis by Wang et. al (2022), based on the RaCE-NMA model."}
cumulativeprobplot_ranks(mcmc=mcmc_results_casestudy, names=treatments)
```
```{r, fig.cap="Table 4: SUCRA and MNBT statistics for each intervention in a network meta-analysis by Wang et. al (2022), based on the RaCE-NMA model."}
calculate_SUCRA_MNBT(mcmc=mcmc_results_casestudy,names=treatments,level=0.50)
```

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/clusterplot_ranks.R
\name{clusterplot_ranks}
\alias{clusterplot_ranks}
\title{Create a posterior clustering matrix for the interventions based on RaCE NMA models}
\usage{
clusterplot_ranks(data = NULL, mcmc = NULL, names = NULL, label_ranks = NULL)
}
\arguments{
\item{data}{A NxJ matrix of data, where N is the number of observations and J the number of treatments. This feature is designed to display results from a standard NMA study.}

\item{mcmc}{MCMC draws from the RaCE NMA model, in the form of the model output of the \code{mcmc_RCMVN} function.}

\item{names}{A vector of intervention names (optional)}

\item{label_ranks}{A vector containing rank levels for which posterior rank probabilities should be displayed within the clustering matrix. Only non-zero probabilities are displayed. Defaults to \code{NULL}, indicating no probabilities are displayed as text.}
}
\value{
A ggplot of a posterior clustering matrix for the interventions.
}
\description{
This function creates a posterior clustering matrix for the interventions in the form of a ggplot.
}
\examples{
data("toy_data")
mcmc <- mcmc_raceNMA(posterior=toy_data,iter=500,nu_iter=2,chains=1)
clusterplot_ranks(mcmc=mcmc,names=paste0("Treatment ",1:10),label_ranks=1:3)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/wang_posterior.R
\docType{data}
\name{wang_posterior}
\alias{wang_posterior}
\title{Posterior relative treatment effects for non-baseline treatments based on Wang et. al (2022)}
\format{
data.frame in which the (i,j) entry is the relative treatment effect of treatment j in posterior draw i.
}
\usage{
wang_posterior
}
\description{
The dataset includes relative treatment effects for 10 non-baseline treatments across 60k posterior
draws based on an NMA study by Wang et. al (2022).
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mcmc_raceNMA.R
\name{mcmc_raceNMA}
\alias{mcmc_raceNMA}
\title{Fit a Bayesian Rank-Clustered Estimation model for Network Meta-Analysis (RaCE-NMA) using multiple MCMC chains}
\usage{
mcmc_raceNMA(
  posterior = NULL,
  mu_hat = NULL,
  cov = NULL,
  s = NULL,
  mu0 = NULL,
  sigma0 = NULL,
  tau = NULL,
  nu0 = NULL,
  iter = 4000,
  nu_iter = 5,
  chains = 2,
  burn_prop = 0.5,
  thin = 1,
  seed = NULL,
  verbose = TRUE
)
}
\arguments{
\item{posterior}{A matrix of posterior draws of relative intervention effects based on a previous NMA. The (i,j) is the ith draw of the effect of intervention j.}

\item{mu_hat}{A vector of estimated average relative intervention effects based on a previous NMA. The jth entry is the effect of intervention j. Ignored if \code{posterior} is supplied.}

\item{cov}{A variance covariance matrix of relative intervention effects based on a previous NMA. The (i,j) entry is the covariane between intervention i and j's effects. Ignored if \code{posterior} is supplied.}

\item{s}{A vector of the estimated standard deviations of each intervention. The jth entry is the standard deviation of intervention j. Ignored if \code{posterior} is supplied.}

\item{mu0}{The hyperparameter mu0. If \code{NULL}, set to mean(mu_hat).}

\item{sigma0}{The hyperparameter sigma_0. If \code{NULL}, set to sqrt(10*var(mu_hat)) which aims to be minimally informative.}

\item{tau}{The standard deviation of the Metropolis Hastings proposal distribution. If \code{NULL}, set to min(|mu_hat_i-mu_hat_j|).}

\item{nu0}{A numeric vector for the initialization of worth parameters, mu, in the MCMC algorithm. Default to \code{NULL}, indicating random initialization.}

\item{iter}{A numeric indicating the total number of outer MCMC iterations (i.e., the number of times the partition is updated in the Gibbs sampler).}

\item{nu_iter}{A numeric indicating the number of times each worth parameter is drawn per update of the parameter partition. There will be a total of \code{iter}x\code{nu_iter} samples from the posterior.}

\item{chains}{A numeric indicating the total number of independent MCMC chains to be run.}

\item{burn_prop}{A numeric between 0 and 1 indicating the proportion of MCMC samples in each chain to be removed as burn-in.}

\item{thin}{A numeric indicating that only every \code{thin}-th sample should be retained, to save computational memory.}

\item{seed}{A numeric indicating the random seed that should be set before running the first MCMC chain.}

\item{verbose}{A boolean indicating if the function should print progress updates as the MCMC chains run. Default to \code{TRUE}.}
}
\value{
A (\code{chains}x\code{iter}/\code{thin})x(3J+3) matrix of posterior draws, one row per posterior sample of mu, nu, and g, with additional columns indicating the MCMC chain index, iteration index, and number of non-empty partition clusters K of each posterior sample.
}
\description{
This function fits a Bayesian RaCE-NMA model to data from a previous network meta-analysis. The function has input parameters to permit drawing multiple MCMC chains, as well as chain thinning and burn-in.
}
\examples{
mcmc <- mcmc_raceNMA(mu_hat=c(0,0,1,1), s=c(.1,.1,.1,.1), seed=1)
head(mcmc)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fit_raceNMA.R
\name{fit_raceNMA}
\alias{fit_raceNMA}
\title{Fit a Bayesian Rank-Clustered Estimation model for Network Meta-Analysis (RaCE-NMA). Recommended for internal use only; use mcmc_RCMVN instead.}
\usage{
fit_raceNMA(
  posterior = NULL,
  mu_hat = NULL,
  cov = NULL,
  s = NULL,
  mu0 = NULL,
  sigma0 = NULL,
  tau,
  nu0,
  iter,
  nu_iter
)
}
\arguments{
\item{posterior}{A matrix of posterior draws of relative intervention effects based on a previous NMA. The (i,j) is the ith draw of the effect of intervention j.}

\item{mu_hat}{A vector of estimated average relative intervention effects based on a previous NMA. The jth entry is the effect of intervention j. Ignored if \code{posterior} is supplied.}

\item{cov}{A variance covariance matrix of relative intervention effects based on a previous NMA. The (i,j) entry is the covariane between intervention i and j's effects. Ignored if \code{posterior} is supplied.}

\item{s}{A vector of the estimated standard deviations of each intervention. The jth entry is the standard deviation of intervention j. Ignored if \code{posterior} is supplied.}

\item{mu0}{The hyperparameter mu0. If \code{NULL}, set to mean(mu_hat).}

\item{sigma0}{The hyperparameter sigma_0. If \code{NULL}, set to sqrt(10*var(mu_hat)) which aims to be minimally informative.}

\item{tau}{The standard deviation of the Metropolis Hastings proposal distribution. If \code{NULL}, set to min(|mu_hat_i-mu_hat_j|).}

\item{nu0}{A numeric vector for the initialization of worth parameters, mu, in the MCMC algorithm. Default to \code{NULL}, indicating random initialization.}

\item{iter}{A numeric indicating the total number of outer MCMC iterations (i.e., the number of times the partition is updated in the Gibbs sampler).}

\item{nu_iter}{A numeric indicating the number of times each worth parameter is drawn per update of the parameter partition. There will be a total of \code{iter}x\code{nu_iter} samples from the posterior.}
}
\value{
A list of 4 elements: \code{mu}, a (\code{iter}x\code{nu_iter})x\code{J} matrix of approximate posterior draws of the intervention-specific worth parameters, mu; \code{nu} a (\code{iter}x\code{nu_iter})x\code{J} matrix of the unique parameter values corresponding to the jth partition cluster in posterior draw i, \code{g} a a (\code{iter}x\code{nu_iter})x\code{J} matrix indicating the cluster membership of object j in posterior draw i, and \code{K} a vector of the number of non-empty partition clusters in each posterior draw.
}
\description{
This function fits a Bayesian RaCE-NMA model to data from a previous network meta-analysis.
}
\examples{
fit_raceNMA(mu_hat=c(0,0,1,1), s=c(.1,.1,.1,.1), mu0=0.5, sigma0=5, tau=0.5,
          nu0 = NULL, iter = 5000, nu_iter = 2)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/traceplot_K.R
\name{traceplot_K}
\alias{traceplot_K}
\title{Create trace plots for the K parameter in RaCE NMA models}
\usage{
traceplot_K(mcmc)
}
\arguments{
\item{mcmc}{MCMC draws from the RaCE NMA model, in the form of the model output of the \code{mcmc_RCMVN} function.}
}
\value{
A ggplot of trace plots for the K parameter.
}
\description{
This function creates trace plots for the K parameter in the form of a ggplot.
}
\examples{
mcmc <- mcmc_raceNMA(mu_hat=c(0,0,1,1), s=c(.1,.1,.1,.1), seed=1)
traceplot_K(mcmc)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/forestplot_muhat.R
\name{forestplot_muhat}
\alias{forestplot_muhat}
\title{Create posterior forest plots for relative treatment effect estimates from a standard or RaCE NMA study}
\usage{
forestplot_muhat(
  data = NULL,
  mcmc = NULL,
  names = NULL,
  level = 0.95,
  order_by_average = TRUE
)
}
\arguments{
\item{data}{A NxJ matrix of data to display as a forest plot, where N is the number of observations and J the number of treatments. This feature is designed for use to display a forest plot of results from a standard NMA study.}

\item{mcmc}{MCMC draws from the RaCE NMA model, in the form of the model output of the \code{mcmc_RCMVN} function.}

\item{names}{A vector of intervention names (optional)}

\item{level}{A numeric indicating the desired credible level to be displayed, as a proportion. Defaults to 0.95.}

\item{order_by_average}{A boolean indicating if plot should order treatments by their average treatment effect.}
}
\value{
A ggplot of posterior forest plots for the mu parameter.
}
\description{
This function creates posterior forest plots for relative treatment effect estimates from a standard or RaCE NMA study.
}
\examples{
data("toy_data")
forestplot_muhat(data=toy_data,names=paste0("Treatment ",1:4))
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cumulativeprobplot_ranks.R
\name{cumulativeprobplot_ranks}
\alias{cumulativeprobplot_ranks}
\title{Create a cumulative ranking plot in RaCE NMA models}
\usage{
cumulativeprobplot_ranks(data = NULL, mcmc = NULL, names = NULL)
}
\arguments{
\item{data}{A NxJ matrix of data, where N is the number of observations and J the number of treatments. This feature is designed to display results from a standard NMA study.}

\item{mcmc}{MCMC draws from the RaCE NMA model, in the form of the model output of the \code{mcmc_RCMVN} function.}

\item{names}{A vector of intervention names (optional)}
}
\value{
A ggplot of a cumulative ranking plot.
}
\description{
This function creates a cumulative ranking plot in the form of a ggplot.
}
\examples{
mcmc <- mcmc_raceNMA(mu_hat=c(0,0,1,1), s=c(.1,.1,.1,.1), seed=1)
cumulativeprobplot_ranks(mcmc=mcmc,names=paste0("Treatment ",1:4))
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/toy_data.R
\docType{data}
\name{toy_data}
\alias{toy_data}
\title{Toy data of posterior relative treatment effects}
\format{
data.frame in which the (i,j) entry is the relative treatment effect of treatment j in posterior draw i.
}
\usage{
toy_data
}
\description{
The dataset includes relative treatment effects for 4 treatments across 10k posterior
draws, as studied in Simulation Study 2 of Pearce and Zhou (2025).
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/calculate_Rhat.R
\name{calculate_Rhat}
\alias{calculate_Rhat}
\title{Calculate Gelman Diagnostics for Fitted RaCE NMA Models}
\usage{
calculate_Rhat(mcmc, names = NULL, level = 0.95, multivariate = FALSE)
}
\arguments{
\item{mcmc}{MCMC draws from the RaCE NMA model, in the form of the model output of the \code{mcmc_RCMVN} function.}

\item{names}{A vector of intervention names (optional)}

\item{level}{The \code{level} parameter from the \code{gelman.diag} function in the \code{coda} package. Defaults to 0.95.}

\item{multivariate}{The \code{multivariate} parameter from the \code{gelman.diag} function in the \code{coda} package. Defaults to FALSE.}
}
\value{
Gelman diagnostics for the inputted MCMC chains, in the format of the output of the \code{gelman.diag} function in the \code{coda} package.
}
\description{
This function applies MCMC outputs from the mcmc_RCMVN package to the gelman.diag function in the coda package.
}
\examples{
mcmc <- mcmc_raceNMA(mu_hat=c(0,0,1,1), s=c(.1,.1,.1,.1), seed=1)
calculate_Rhat(mcmc,names=paste0("Treatment ",1:4))
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sample_partition_correlation.R
\name{sample_partition_correlation}
\alias{sample_partition_correlation}
\title{Partition sampling in Bayesian RaCE-NMA models (internal use only)}
\usage{
sample_partition_correlation(
  mu_hat,
  J,
  nu,
  g,
  K,
  mu0,
  sigma0,
  cov,
  tau = tau,
  b_g = 0.5,
  d_g = 0.5
)
}
\arguments{
\item{mu_hat}{A vector of estimated average relative intervention effects based on a previous NMA. The jth entry is the effect of intervention j.}

\item{J}{A numeric indicating the total number of interventions being compared.}

\item{nu}{A vector indicating current values for nu in the Gibbs sampler.}

\item{g}{A vector indicating current values for g in the Gibbs sampler.}

\item{K}{A vector indicating current values for K in the Gibbs sampler.}

\item{mu0}{The hyperparameter mu0, usually specified as the grand mean of the average intervention effects.}

\item{sigma0}{The hyperparameter sigma_0, usually a large number as to be minimally informative.}

\item{cov}{A variance covariance matrix of relative intervention effects based on a previous NMA. The (i,j) entry is the covariane between intervention i and j's effects.}

\item{tau}{The standard deviation of the Metropolis Hastings proposal distribution.}

\item{b_g}{The probability of "birth"ing a new partition cluster, if possible. Default is 0.5.}

\item{d_g}{The probability of "death"ing an existing partition cluster, if possible. Default is 0.5.}
}
\value{
A list containing updated values for g, nu, and K.
}
\description{
This function implements a reversible jump MCMC procedure for updating the parameter partition in Bayesian Rank-Clustered Estimation for Network Meta-Analysis models in the case when we assume correlation among treatment effects. For internal use only.
}
\examples{
sample_partition_correlation(mu_hat=c(1,1,1),J=3,nu=1,g=c(1,1,1),K=1,mu0=1,sigma0=1,tau=0.1)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/calculate_SUCRA_MNBT.R
\name{calculate_SUCRA_MNBT}
\alias{calculate_SUCRA_MNBT}
\title{Calculate SUCRA and MNBT based on MCMC draws in NMA or RaCE-NMA models}
\usage{
calculate_SUCRA_MNBT(data = NULL, mcmc = NULL, level = 0.5, names = NULL)
}
\arguments{
\item{data}{A NxJ matrix of data, where N is the number of observations and J the number of treatments. This feature is designed to display results from a standard NMA study.}

\item{mcmc}{MCMC draws from the RaCE NMA model, in the form of the model output of the \code{mcmc_RCMVN} function.}

\item{level}{The \code{level} level for the interval estimate of MNBT. Defaults to 0.50.}

\item{names}{A vector of intervention names (optional)}
}
\value{
A table containing SUCRA and MNBT values for each treatment, ordered by descending SUCRA values.
}
\description{
This function creates a results table of SUCRA and Median Number of Better Treatments (MNBT) based on
MCMC draws from a standard NMA model or a fitted RaCE-NMA model.
}
\examples{
mcmc <- mcmc_raceNMA(mu_hat=c(0,0,1,1), s=c(.1,.1,.1,.1), seed=1)
calculate_SUCRA_MNBT(mcmc=mcmc)
}
